declare module "windows.devices.sms" {
  export class SmsEncodedLength {
    segmentCount: Number;
    characterCountLastSegment: Number;
    charactersPerSegment: Number;
    byteCountLastSegment: Number;
    bytesPerSegment: Number;
    constructor();
  }

  export enum SmsMessageClass {
    none,
    class0,
    class1,
    class2,
    class3,
  }

  export enum SmsDataFormat {
    unknown,
    cdmaSubmit,
    gsmSubmit,
    cdmaDeliver,
    gsmDeliver,
  }

  export enum SmsEncoding {
    unknown,
    optimal,
    sevenBitAscii,
    unicode,
    gsmSevenBit,
  }

  export enum SmsMessageFilter {
    all,
    unread,
    read,
    sent,
    draft,
  }

  export enum SmsMessageType {
    binary,
    text,
  }

  export enum CellularClass {
    none,
    gsm,
    cdma,
  }

  export enum SmsDeviceStatus {
    off,
    ready,
    simNotInserted,
    badSim,
    deviceFailure,
    subscriptionNotActivated,
    deviceLocked,
    deviceBlocked,
  }

  export class ISmsMessage {
    id: Number;
    messageClass: SmsMessageClass;
    constructor();

  }

  export class ISmsBinaryMessage {
    format: SmsDataFormat;
    constructor();

    getData(): Array<Number>;

    setData(value: Array<Number>): void;

  }

  export class SmsBinaryMessage {
    id: Number;
    messageClass: SmsMessageClass;
    format: SmsDataFormat;
    constructor();

    getData(): Array<Number>;

    setData(value: Array<Number>): void;

  }

  export class ISmsTextMessage {
    body: String;
    encoding: SmsEncoding;
    from: String;
    partCount: Number;
    partNumber: Number;
    partReferenceId: Number;
    timestamp: Date;
    to: String;
    constructor();

    toBinaryMessages(format: SmsDataFormat): Object;

  }

  export class SmsTextMessage {
    to: String;
    from: String;
    encoding: SmsEncoding;
    body: String;
    partCount: Number;
    partNumber: Number;
    partReferenceId: Number;
    timestamp: Date;
    id: Number;
    messageClass: SmsMessageClass;
    constructor();

    static fromBinaryMessage(binaryMessage: SmsBinaryMessage): SmsTextMessage;


    static fromBinaryData(format: SmsDataFormat, value: Array<Number>): SmsTextMessage;


    toBinaryMessages(format: SmsDataFormat): Object;

  }

  export class DeleteSmsMessageOperation {
    completed: Object;
    errorCode: Number;
    id: Number;
    status: Number;
    constructor();

    getResults(): void;

    cancel(): void;

    close(): void;

  }

  export class DeleteSmsMessagesOperation {
    completed: Object;
    errorCode: Number;
    id: Number;
    status: Number;
    constructor();

    getResults(): void;

    cancel(): void;

    close(): void;

  }

  export class GetSmsMessageOperation {
    completed: Object;
    errorCode: Number;
    id: Number;
    status: Number;
    constructor();

    getResults(): ISmsMessage;

    cancel(): void;

    close(): void;

  }

  export class GetSmsMessagesOperation {
    errorCode: Number;
    id: Number;
    status: Number;
    progress: Object;
    completed: Object;
    constructor();

    getResults(): Object;

    cancel(): void;

    close(): void;

  }

  export class SmsDeviceMessageStore {
    maxMessages: Number;
    constructor();

    deleteMessageAsync(messageId: Number, callback: (error: Error) => void): void ;

    deleteMessagesAsync(messageFilter: SmsMessageFilter, callback: (error: Error) => void): void ;

    getMessageAsync(messageId: Number, callback: (error: Error, result: ISmsMessage) => void): void ;

    getMessagesAsync(messageFilter: SmsMessageFilter, callback: (error: Error, result: Object) => void): void ;

  }

  export class SendSmsMessageOperation {
    completed: Object;
    errorCode: Number;
    id: Number;
    status: Number;
    constructor();

    getResults(): void;

    cancel(): void;

    close(): void;

  }

  export class SmsMessageReceivedEventArgs {
    binaryMessage: SmsBinaryMessage;
    textMessage: SmsTextMessage;
    constructor();

  }

  export class SmsDevice {
    accountPhoneNumber: String;
    cellularClass: CellularClass;
    deviceStatus: SmsDeviceStatus;
    messageStore: SmsDeviceMessageStore;
    constructor();

    static fromNetworkAccountIdAsync(networkAccountId: String, callback: (error: Error, result: SmsDevice) => void): void ;


    static fromIdAsync(deviceId: String, callback: (error: Error, result: SmsDevice) => void): void ;


    static getDefaultAsync(callback: (error: Error, result: SmsDevice) => void): void ;


    static getDeviceSelector(): String;


    sendMessageAsync(message: ISmsMessage, callback: (error: Error) => void): void ;

    calculateLength(message: SmsTextMessage): SmsEncodedLength;

    addListener(type: "SmsDeviceStatusChanged", listener: (ev: Event) => void): void ;
    removeListener(type: "SmsDeviceStatusChanged", listener: (ev: Event) => void): void ;
    on(type: "SmsDeviceStatusChanged", listener: (ev: Event) => void): void ;
    off(type: "SmsDeviceStatusChanged", listener: (ev: Event) => void): void ;
    
    addListener(type: "SmsMessageReceived", listener: (ev: Event) => void): void ;
    removeListener(type: "SmsMessageReceived", listener: (ev: Event) => void): void ;
    on(type: "SmsMessageReceived", listener: (ev: Event) => void): void ;
    off(type: "SmsMessageReceived", listener: (ev: Event) => void): void ;
    
    addListener(type: string, listener: (ev: Event) => void): void ;
    removeListener(type: string, listener: (ev: Event) => void): void ;
    on(type: string, listener: (ev: Event) => void): void ;
    off(type: string, listener: (ev: Event) => void): void ;
    

  }

  export class GetSmsDeviceOperation {
    completed: Object;
    errorCode: Number;
    id: Number;
    status: Number;
    constructor();

    getResults(): SmsDevice;

    cancel(): void;

    close(): void;

  }

  export class ISmsDevice {
    accountPhoneNumber: String;
    cellularClass: CellularClass;
    deviceStatus: SmsDeviceStatus;
    messageStore: SmsDeviceMessageStore;
    constructor();

    sendMessageAsync(message: ISmsMessage, callback: (error: Error) => void): void ;

    calculateLength(message: SmsTextMessage): SmsEncodedLength;

    addListener(type: "SmsDeviceStatusChanged", listener: (ev: Event) => void): void ;
    removeListener(type: "SmsDeviceStatusChanged", listener: (ev: Event) => void): void ;
    on(type: "SmsDeviceStatusChanged", listener: (ev: Event) => void): void ;
    off(type: "SmsDeviceStatusChanged", listener: (ev: Event) => void): void ;
    
    addListener(type: "SmsMessageReceived", listener: (ev: Event) => void): void ;
    removeListener(type: "SmsMessageReceived", listener: (ev: Event) => void): void ;
    on(type: "SmsMessageReceived", listener: (ev: Event) => void): void ;
    off(type: "SmsMessageReceived", listener: (ev: Event) => void): void ;
    
    addListener(type: string, listener: (ev: Event) => void): void ;
    removeListener(type: string, listener: (ev: Event) => void): void ;
    on(type: string, listener: (ev: Event) => void): void ;
    off(type: string, listener: (ev: Event) => void): void ;
    

  }

  export class SmsReceivedEventDetails {
    deviceId: String;
    messageIndex: Number;
    binaryMessage: SmsBinaryMessage;
    messageClass: SmsMessageClass;
    constructor();

  }

}



