// Copyright (c) Microsoft Corporation
// All rights reserved. 
//
// Licensed under the Apache License, Version 2.0 (the ""License""); you may not use this file except in compliance with the License. You may obtain a copy of the License at http://www.apache.org/licenses/LICENSE-2.0 
//
// THIS CODE IS PROVIDED ON AN  *AS IS* BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, EITHER EXPRESS OR IMPLIED, INCLUDING WITHOUT LIMITATION ANY IMPLIED WARRANTIES OR CONDITIONS OF TITLE, FITNESS FOR A PARTICULAR PURPOSE, MERCHANTABLITY OR NON-INFRINGEMENT. 
//
// See the Apache Version 2.0 License for specific language governing permissions and limitations under the License.

#define NTDDI_VERSION 0x06010000

#include <v8.h>
#include <string>
#include <node_object_wrap.h>
#include <ppltasks.h>
#include "CollectionsConverter.h"
#include "CollectionsWrap.h"
#include "node-async.h"
#include "NodeRtUtils.h"
#include "OpaqueWrapper.h"
#include "WrapperBase.h"

#using <Windows.WinMD>

// this undefs fixes the issues of compiling Windows.Data.Json, Windows.Storag.FileProperties, and Windows.Stroage.Search
// Some of the node header files brings windows definitions with the same names as some of the WinRT methods
#undef DocumentProperties
#undef GetObject
#undef CreateEvent
#undef FindText
#undef SendMessage

const char* REGISTRATION_TOKEN_MAP_PROPERTY_NAME = "__registrationTokenMap__";

using namespace v8;
using namespace node;
using namespace concurrency;

namespace NodeRT { namespace Windows { namespace Devices { namespace Sms { 
  v8::Handle<v8::Value> WrapISmsMessage(::Windows::Devices::Sms::ISmsMessage^ wintRtInstance);
  ::Windows::Devices::Sms::ISmsMessage^ UnwrapISmsMessage(Handle<Value> value);
  
  v8::Handle<v8::Value> WrapISmsBinaryMessage(::Windows::Devices::Sms::ISmsBinaryMessage^ wintRtInstance);
  ::Windows::Devices::Sms::ISmsBinaryMessage^ UnwrapISmsBinaryMessage(Handle<Value> value);
  
  v8::Handle<v8::Value> WrapSmsBinaryMessage(::Windows::Devices::Sms::SmsBinaryMessage^ wintRtInstance);
  ::Windows::Devices::Sms::SmsBinaryMessage^ UnwrapSmsBinaryMessage(Handle<Value> value);
  
  v8::Handle<v8::Value> WrapISmsTextMessage(::Windows::Devices::Sms::ISmsTextMessage^ wintRtInstance);
  ::Windows::Devices::Sms::ISmsTextMessage^ UnwrapISmsTextMessage(Handle<Value> value);
  
  v8::Handle<v8::Value> WrapSmsTextMessage(::Windows::Devices::Sms::SmsTextMessage^ wintRtInstance);
  ::Windows::Devices::Sms::SmsTextMessage^ UnwrapSmsTextMessage(Handle<Value> value);
  
  v8::Handle<v8::Value> WrapDeleteSmsMessageOperation(::Windows::Devices::Sms::DeleteSmsMessageOperation^ wintRtInstance);
  ::Windows::Devices::Sms::DeleteSmsMessageOperation^ UnwrapDeleteSmsMessageOperation(Handle<Value> value);
  
  v8::Handle<v8::Value> WrapDeleteSmsMessagesOperation(::Windows::Devices::Sms::DeleteSmsMessagesOperation^ wintRtInstance);
  ::Windows::Devices::Sms::DeleteSmsMessagesOperation^ UnwrapDeleteSmsMessagesOperation(Handle<Value> value);
  
  v8::Handle<v8::Value> WrapGetSmsMessageOperation(::Windows::Devices::Sms::GetSmsMessageOperation^ wintRtInstance);
  ::Windows::Devices::Sms::GetSmsMessageOperation^ UnwrapGetSmsMessageOperation(Handle<Value> value);
  
  v8::Handle<v8::Value> WrapGetSmsMessagesOperation(::Windows::Devices::Sms::GetSmsMessagesOperation^ wintRtInstance);
  ::Windows::Devices::Sms::GetSmsMessagesOperation^ UnwrapGetSmsMessagesOperation(Handle<Value> value);
  
  v8::Handle<v8::Value> WrapSmsDeviceMessageStore(::Windows::Devices::Sms::SmsDeviceMessageStore^ wintRtInstance);
  ::Windows::Devices::Sms::SmsDeviceMessageStore^ UnwrapSmsDeviceMessageStore(Handle<Value> value);
  
  v8::Handle<v8::Value> WrapSendSmsMessageOperation(::Windows::Devices::Sms::SendSmsMessageOperation^ wintRtInstance);
  ::Windows::Devices::Sms::SendSmsMessageOperation^ UnwrapSendSmsMessageOperation(Handle<Value> value);
  
  v8::Handle<v8::Value> WrapSmsMessageReceivedEventArgs(::Windows::Devices::Sms::SmsMessageReceivedEventArgs^ wintRtInstance);
  ::Windows::Devices::Sms::SmsMessageReceivedEventArgs^ UnwrapSmsMessageReceivedEventArgs(Handle<Value> value);
  
  v8::Handle<v8::Value> WrapSmsDevice(::Windows::Devices::Sms::SmsDevice^ wintRtInstance);
  ::Windows::Devices::Sms::SmsDevice^ UnwrapSmsDevice(Handle<Value> value);
  
  v8::Handle<v8::Value> WrapGetSmsDeviceOperation(::Windows::Devices::Sms::GetSmsDeviceOperation^ wintRtInstance);
  ::Windows::Devices::Sms::GetSmsDeviceOperation^ UnwrapGetSmsDeviceOperation(Handle<Value> value);
  
  v8::Handle<v8::Value> WrapISmsDevice(::Windows::Devices::Sms::ISmsDevice^ wintRtInstance);
  ::Windows::Devices::Sms::ISmsDevice^ UnwrapISmsDevice(Handle<Value> value);
  
  v8::Handle<v8::Value> WrapSmsReceivedEventDetails(::Windows::Devices::Sms::SmsReceivedEventDetails^ wintRtInstance);
  ::Windows::Devices::Sms::SmsReceivedEventDetails^ UnwrapSmsReceivedEventDetails(Handle<Value> value);
  


  static v8::Handle<v8::Value> InitSmsMessageClassEnum(const Handle<Object> exports)
  {
    HandleScope scope;
    
    Handle<Object> enumObject = Object::New();
    exports->Set(String::NewSymbol("SmsMessageClass"), enumObject);

    enumObject->Set(String::NewSymbol("none"), Integer::New(0));
    enumObject->Set(String::NewSymbol("class0"), Integer::New(1));
    enumObject->Set(String::NewSymbol("class1"), Integer::New(2));
    enumObject->Set(String::NewSymbol("class2"), Integer::New(3));
    enumObject->Set(String::NewSymbol("class3"), Integer::New(4));

    return scope.Close(Undefined());
  }


  static v8::Handle<v8::Value> InitSmsDataFormatEnum(const Handle<Object> exports)
  {
    HandleScope scope;
    
    Handle<Object> enumObject = Object::New();
    exports->Set(String::NewSymbol("SmsDataFormat"), enumObject);

    enumObject->Set(String::NewSymbol("unknown"), Integer::New(0));
    enumObject->Set(String::NewSymbol("cdmaSubmit"), Integer::New(1));
    enumObject->Set(String::NewSymbol("gsmSubmit"), Integer::New(2));
    enumObject->Set(String::NewSymbol("cdmaDeliver"), Integer::New(3));
    enumObject->Set(String::NewSymbol("gsmDeliver"), Integer::New(4));

    return scope.Close(Undefined());
  }


  static v8::Handle<v8::Value> InitSmsEncodingEnum(const Handle<Object> exports)
  {
    HandleScope scope;
    
    Handle<Object> enumObject = Object::New();
    exports->Set(String::NewSymbol("SmsEncoding"), enumObject);

    enumObject->Set(String::NewSymbol("unknown"), Integer::New(0));
    enumObject->Set(String::NewSymbol("optimal"), Integer::New(1));
    enumObject->Set(String::NewSymbol("sevenBitAscii"), Integer::New(2));
    enumObject->Set(String::NewSymbol("unicode"), Integer::New(3));
    enumObject->Set(String::NewSymbol("gsmSevenBit"), Integer::New(4));

    return scope.Close(Undefined());
  }


  static v8::Handle<v8::Value> InitSmsMessageFilterEnum(const Handle<Object> exports)
  {
    HandleScope scope;
    
    Handle<Object> enumObject = Object::New();
    exports->Set(String::NewSymbol("SmsMessageFilter"), enumObject);

    enumObject->Set(String::NewSymbol("all"), Integer::New(0));
    enumObject->Set(String::NewSymbol("unread"), Integer::New(1));
    enumObject->Set(String::NewSymbol("read"), Integer::New(2));
    enumObject->Set(String::NewSymbol("sent"), Integer::New(3));
    enumObject->Set(String::NewSymbol("draft"), Integer::New(4));

    return scope.Close(Undefined());
  }


  static v8::Handle<v8::Value> InitSmsMessageTypeEnum(const Handle<Object> exports)
  {
    HandleScope scope;
    
    Handle<Object> enumObject = Object::New();
    exports->Set(String::NewSymbol("SmsMessageType"), enumObject);

    enumObject->Set(String::NewSymbol("binary"), Integer::New(0));
    enumObject->Set(String::NewSymbol("text"), Integer::New(1));

    return scope.Close(Undefined());
  }


  static v8::Handle<v8::Value> InitCellularClassEnum(const Handle<Object> exports)
  {
    HandleScope scope;
    
    Handle<Object> enumObject = Object::New();
    exports->Set(String::NewSymbol("CellularClass"), enumObject);

    enumObject->Set(String::NewSymbol("none"), Integer::New(0));
    enumObject->Set(String::NewSymbol("gsm"), Integer::New(1));
    enumObject->Set(String::NewSymbol("cdma"), Integer::New(2));

    return scope.Close(Undefined());
  }


  static v8::Handle<v8::Value> InitSmsDeviceStatusEnum(const Handle<Object> exports)
  {
    HandleScope scope;
    
    Handle<Object> enumObject = Object::New();
    exports->Set(String::NewSymbol("SmsDeviceStatus"), enumObject);

    enumObject->Set(String::NewSymbol("off"), Integer::New(0));
    enumObject->Set(String::NewSymbol("ready"), Integer::New(1));
    enumObject->Set(String::NewSymbol("simNotInserted"), Integer::New(2));
    enumObject->Set(String::NewSymbol("badSim"), Integer::New(3));
    enumObject->Set(String::NewSymbol("deviceFailure"), Integer::New(4));
    enumObject->Set(String::NewSymbol("subscriptionNotActivated"), Integer::New(5));
    enumObject->Set(String::NewSymbol("deviceLocked"), Integer::New(6));
    enumObject->Set(String::NewSymbol("deviceBlocked"), Integer::New(7));

    return scope.Close(Undefined());
  }



  
  static bool IsSmsEncodedLengthJsObject(Handle<Value> value)
  {
    if (!value->IsObject())
    {
      return false;
    }

    Handle<String> symbol;
    Handle<Object> obj = value.As<Object>();

    symbol = String::NewSymbol("segmentCount");
    if (obj->Has(symbol))
    {
      if (!obj->Get(symbol)->IsUint32())
      {
          return false;
      }
    }
    
    symbol = String::NewSymbol("characterCountLastSegment");
    if (obj->Has(symbol))
    {
      if (!obj->Get(symbol)->IsUint32())
      {
          return false;
      }
    }
    
    symbol = String::NewSymbol("charactersPerSegment");
    if (obj->Has(symbol))
    {
      if (!obj->Get(symbol)->IsUint32())
      {
          return false;
      }
    }
    
    symbol = String::NewSymbol("byteCountLastSegment");
    if (obj->Has(symbol))
    {
      if (!obj->Get(symbol)->IsUint32())
      {
          return false;
      }
    }
    
    symbol = String::NewSymbol("bytesPerSegment");
    if (obj->Has(symbol))
    {
      if (!obj->Get(symbol)->IsUint32())
      {
          return false;
      }
    }
    
    return true;
  }

  ::Windows::Devices::Sms::SmsEncodedLength SmsEncodedLengthFromJsObject(Handle<Value> value)
  {
    HandleScope scope;
    ::Windows::Devices::Sms::SmsEncodedLength returnValue;
    
    if (!value->IsObject())
    {
      ThrowException(Exception::TypeError(NodeRT::Utils::NewString(L"Unexpected type, expected an object")));
      return returnValue;
    }

    Handle<Object> obj = value.As<Object>();
    Handle<String> symbol;

    symbol = String::NewSymbol("segmentCount");
    if (obj->Has(symbol))
    {
      returnValue.SegmentCount = static_cast<unsigned int>(obj->Get(symbol)->IntegerValue());
    }
    
    symbol = String::NewSymbol("characterCountLastSegment");
    if (obj->Has(symbol))
    {
      returnValue.CharacterCountLastSegment = static_cast<unsigned int>(obj->Get(symbol)->IntegerValue());
    }
    
    symbol = String::NewSymbol("charactersPerSegment");
    if (obj->Has(symbol))
    {
      returnValue.CharactersPerSegment = static_cast<unsigned int>(obj->Get(symbol)->IntegerValue());
    }
    
    symbol = String::NewSymbol("byteCountLastSegment");
    if (obj->Has(symbol))
    {
      returnValue.ByteCountLastSegment = static_cast<unsigned int>(obj->Get(symbol)->IntegerValue());
    }
    
    symbol = String::NewSymbol("bytesPerSegment");
    if (obj->Has(symbol))
    {
      returnValue.BytesPerSegment = static_cast<unsigned int>(obj->Get(symbol)->IntegerValue());
    }
    
    return returnValue;
  }

  Handle<Value> SmsEncodedLengthToJsObject(::Windows::Devices::Sms::SmsEncodedLength value)
  {
    HandleScope scope;

    Handle<Object> obj = Object::New();

    obj->Set(String::NewSymbol("segmentCount"), Integer::New(value.SegmentCount));
    obj->Set(String::NewSymbol("characterCountLastSegment"), Integer::New(value.CharacterCountLastSegment));
    obj->Set(String::NewSymbol("charactersPerSegment"), Integer::New(value.CharactersPerSegment));
    obj->Set(String::NewSymbol("byteCountLastSegment"), Integer::New(value.ByteCountLastSegment));
    obj->Set(String::NewSymbol("bytesPerSegment"), Integer::New(value.BytesPerSegment));
    
    return scope.Close(obj);
  }

  
  class ISmsMessage : public WrapperBase
  {
  public:    
    static v8::Handle<v8::Value> Init(const Handle<Object> exports)
    {
      HandleScope scope;
      
      s_constructorTemplate = Persistent<FunctionTemplate>::New(FunctionTemplate::New(New));
      s_constructorTemplate->SetClassName(String::NewSymbol("ISmsMessage"));
      s_constructorTemplate->InstanceTemplate()->SetInternalFieldCount(1);
      
                              
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("id"), IdGetter);
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("messageClass"), MessageClassGetter);
      
      Local<Function> constructor = s_constructorTemplate->GetFunction();


      exports->Set(String::NewSymbol("ISmsMessage"), constructor);
      return scope.Close(Undefined());
    }


    virtual ::Platform::Object^ GetObjectInstance() const override
    {
      return _instance;
    }

  private:
    
    ISmsMessage(::Windows::Devices::Sms::ISmsMessage^ instance)
    {
      _instance = instance;
    }
    
    
    static v8::Handle<v8::Value> New(const v8::Arguments& args)
    {
      HandleScope scope;

      // in case the constructor was called without the new operator
      if (!s_constructorTemplate->HasInstance(args.This()))
      {
        if (args.Length() > 0)
        {
          std::unique_ptr<Handle<Value> []> constructorArgs(new Handle<Value>[args.Length()]);

          Handle<Value> *argsPtr = constructorArgs.get();
          for (int i = 0; i < args.Length(); i++)
          {
            argsPtr[i] = args[i];
          }

          return s_constructorTemplate->GetFunction()->CallAsConstructor(args.Length(), constructorArgs.get());
        }
        else
        {
          return s_constructorTemplate->GetFunction()->CallAsConstructor(args.Length(), nullptr);
        }
      }
      
      ::Windows::Devices::Sms::ISmsMessage^ winRtInstance;


      if (args.Length() == 1 && OpaqueWrapper::IsOpaqueWrapper(args[0]) &&
        NodeRT::Utils::IsWinRtWrapperOf<::Windows::Devices::Sms::ISmsMessage^>(args[0]))
      {
        try 
        {
          winRtInstance = (::Windows::Devices::Sms::ISmsMessage^) NodeRT::Utils::GetObjectInstance(args[0]);
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Invalid arguments, no suitable constructor found")));
        return scope.Close(Undefined());
      }

      args.This()->SetHiddenValue(String::NewSymbol("__winRtInstance__"), True());

      ISmsMessage *wrapperInstance = new ISmsMessage(winRtInstance);
      wrapperInstance->Wrap(args.This());

      return args.This();
    }


  



    static Handle<Value> IdGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Devices::Sms::ISmsMessage^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      ISmsMessage *wrapper = ISmsMessage::Unwrap<ISmsMessage>(info.This());

      try 
      {
        unsigned int result = wrapper->_instance->Id;
        return scope.Close(Integer::New(result));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    
    static Handle<Value> MessageClassGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Devices::Sms::ISmsMessage^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      ISmsMessage *wrapper = ISmsMessage::Unwrap<ISmsMessage>(info.This());

      try 
      {
        ::Windows::Devices::Sms::SmsMessageClass result = wrapper->_instance->MessageClass;
        return scope.Close(Integer::New(static_cast<int>(result)));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    


  private:
    ::Windows::Devices::Sms::ISmsMessage^ _instance;
    static Persistent<FunctionTemplate> s_constructorTemplate;

    friend v8::Handle<v8::Value> WrapISmsMessage(::Windows::Devices::Sms::ISmsMessage^ wintRtInstance);
    friend ::Windows::Devices::Sms::ISmsMessage^ UnwrapISmsMessage(Handle<Value> value);
    friend bool IsISmsMessageWrapper(Handle<Value> value);
  };
  Persistent<FunctionTemplate> ISmsMessage::s_constructorTemplate;

  v8::Handle<v8::Value> WrapISmsMessage(::Windows::Devices::Sms::ISmsMessage^ winRtInstance)
  {
    HandleScope scope;

    if (winRtInstance == nullptr)
    {
      return scope.Close(Undefined());
    }

    Handle<Object> opaqueWrapper = CreateOpaqueWrapper(winRtInstance);
    Handle<Value> args[] = {opaqueWrapper};
    return scope.Close(ISmsMessage::s_constructorTemplate->GetFunction()->NewInstance(_countof(args), args));
  }

  ::Windows::Devices::Sms::ISmsMessage^ UnwrapISmsMessage(Handle<Value> value)
  {
     return ISmsMessage::Unwrap<ISmsMessage>(value.As<Object>())->_instance;
  }

  void InitISmsMessage(Handle<Object> exports)
  {
    ISmsMessage::Init(exports);
  }

  class ISmsBinaryMessage : public WrapperBase
  {
  public:    
    static v8::Handle<v8::Value> Init(const Handle<Object> exports)
    {
      HandleScope scope;
      
      s_constructorTemplate = Persistent<FunctionTemplate>::New(FunctionTemplate::New(New));
      s_constructorTemplate->SetClassName(String::NewSymbol("ISmsBinaryMessage"));
      s_constructorTemplate->InstanceTemplate()->SetInternalFieldCount(1);
      
            
      s_constructorTemplate->PrototypeTemplate()->Set(String::NewSymbol("getData"), FunctionTemplate::New(GetData)->GetFunction());
      s_constructorTemplate->PrototypeTemplate()->Set(String::NewSymbol("setData"), FunctionTemplate::New(SetData)->GetFunction());
      
                        
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("format"), FormatGetter, FormatSetter);
      
      Local<Function> constructor = s_constructorTemplate->GetFunction();


      exports->Set(String::NewSymbol("ISmsBinaryMessage"), constructor);
      return scope.Close(Undefined());
    }


    virtual ::Platform::Object^ GetObjectInstance() const override
    {
      return _instance;
    }

  private:
    
    ISmsBinaryMessage(::Windows::Devices::Sms::ISmsBinaryMessage^ instance)
    {
      _instance = instance;
    }
    
    
    static v8::Handle<v8::Value> New(const v8::Arguments& args)
    {
      HandleScope scope;

      // in case the constructor was called without the new operator
      if (!s_constructorTemplate->HasInstance(args.This()))
      {
        if (args.Length() > 0)
        {
          std::unique_ptr<Handle<Value> []> constructorArgs(new Handle<Value>[args.Length()]);

          Handle<Value> *argsPtr = constructorArgs.get();
          for (int i = 0; i < args.Length(); i++)
          {
            argsPtr[i] = args[i];
          }

          return s_constructorTemplate->GetFunction()->CallAsConstructor(args.Length(), constructorArgs.get());
        }
        else
        {
          return s_constructorTemplate->GetFunction()->CallAsConstructor(args.Length(), nullptr);
        }
      }
      
      ::Windows::Devices::Sms::ISmsBinaryMessage^ winRtInstance;


      if (args.Length() == 1 && OpaqueWrapper::IsOpaqueWrapper(args[0]) &&
        NodeRT::Utils::IsWinRtWrapperOf<::Windows::Devices::Sms::ISmsBinaryMessage^>(args[0]))
      {
        try 
        {
          winRtInstance = (::Windows::Devices::Sms::ISmsBinaryMessage^) NodeRT::Utils::GetObjectInstance(args[0]);
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Invalid arguments, no suitable constructor found")));
        return scope.Close(Undefined());
      }

      args.This()->SetHiddenValue(String::NewSymbol("__winRtInstance__"), True());

      ISmsBinaryMessage *wrapperInstance = new ISmsBinaryMessage(winRtInstance);
      wrapperInstance->Wrap(args.This());

      return args.This();
    }


  
    static Handle<Value> GetData(const v8::Arguments& args)
    {
      HandleScope scope;

      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Devices::Sms::ISmsBinaryMessage^>(args.This()))
      {
        return scope.Close(Undefined());
      }

      ISmsBinaryMessage *wrapper = ISmsBinaryMessage::Unwrap<ISmsBinaryMessage>(args.This());

      if (args.Length() == 0)
      {
        try
        {
          ::Platform::Array<unsigned char>^ result;
          result = wrapper->_instance->GetData();
          return scope.Close(NodeRT::Collections::ArrayWrapper<unsigned char>::CreateArrayWrapper(result, 
            [](unsigned char val) -> Handle<Value> {
              return Integer::New(val);
            },
            [](Handle<Value> value) -> bool {
              return value->IsInt32();
            },
            [](Handle<Value> value) -> unsigned char {
              return static_cast<unsigned char>(value->Int32Value());
            }
          ));
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else 
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Bad arguments: no suitable overload found")));
        return scope.Close(Undefined());
      }

      return scope.Close(Undefined());
    }
    static Handle<Value> SetData(const v8::Arguments& args)
    {
      HandleScope scope;

      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Devices::Sms::ISmsBinaryMessage^>(args.This()))
      {
        return scope.Close(Undefined());
      }

      ISmsBinaryMessage *wrapper = ISmsBinaryMessage::Unwrap<ISmsBinaryMessage>(args.This());

      if (args.Length() == 1
        && (NodeRT::Utils::IsWinRtWrapperOf<::Platform::Array<unsigned char>^>(args[0]) || args[0]->IsArray()))
      {
        try
        {
          ::Platform::Array<unsigned char>^ arg0 = 
            [] (v8::Handle<v8::Value> value) -> ::Platform::Array<unsigned char>^
            {
              if (value->IsArray())
              {
                return NodeRT::Collections::JsArrayToWinrtArray<unsigned char>(value.As<Array>(), 
                 [](Handle<Value> value) -> bool {
                   return value->IsInt32();
                 },
                 [](Handle<Value> value) -> unsigned char {
                   return static_cast<unsigned char>(value->Int32Value());
                 }
                );
              }
              else
              {
                return dynamic_cast<::Platform::Array<unsigned char>^>(NodeRT::Utils::GetObjectInstance(value));
              }
            } (args[0]);
          
          wrapper->_instance->SetData(arg0);
          return scope.Close(Undefined());   
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else 
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Bad arguments: no suitable overload found")));
        return scope.Close(Undefined());
      }

      return scope.Close(Undefined());
    }



    static Handle<Value> FormatGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Devices::Sms::ISmsBinaryMessage^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      ISmsBinaryMessage *wrapper = ISmsBinaryMessage::Unwrap<ISmsBinaryMessage>(info.This());

      try 
      {
        ::Windows::Devices::Sms::SmsDataFormat result = wrapper->_instance->Format;
        return scope.Close(Integer::New(static_cast<int>(result)));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    
    static void FormatSetter(Local<String> property, Local<Value> value, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!value->IsInt32())
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Value to set is of unexpected type")));
        return;
      }

      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Devices::Sms::ISmsBinaryMessage^>(info.This()))
      {
        return;
      }

      ISmsBinaryMessage *wrapper = ISmsBinaryMessage::Unwrap<ISmsBinaryMessage>(info.This());

      try 
      {
        
        ::Windows::Devices::Sms::SmsDataFormat winRtValue = static_cast<::Windows::Devices::Sms::SmsDataFormat>(value->Int32Value());

        wrapper->_instance->Format = winRtValue;
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
      }
    }
    


  private:
    ::Windows::Devices::Sms::ISmsBinaryMessage^ _instance;
    static Persistent<FunctionTemplate> s_constructorTemplate;

    friend v8::Handle<v8::Value> WrapISmsBinaryMessage(::Windows::Devices::Sms::ISmsBinaryMessage^ wintRtInstance);
    friend ::Windows::Devices::Sms::ISmsBinaryMessage^ UnwrapISmsBinaryMessage(Handle<Value> value);
    friend bool IsISmsBinaryMessageWrapper(Handle<Value> value);
  };
  Persistent<FunctionTemplate> ISmsBinaryMessage::s_constructorTemplate;

  v8::Handle<v8::Value> WrapISmsBinaryMessage(::Windows::Devices::Sms::ISmsBinaryMessage^ winRtInstance)
  {
    HandleScope scope;

    if (winRtInstance == nullptr)
    {
      return scope.Close(Undefined());
    }

    Handle<Object> opaqueWrapper = CreateOpaqueWrapper(winRtInstance);
    Handle<Value> args[] = {opaqueWrapper};
    return scope.Close(ISmsBinaryMessage::s_constructorTemplate->GetFunction()->NewInstance(_countof(args), args));
  }

  ::Windows::Devices::Sms::ISmsBinaryMessage^ UnwrapISmsBinaryMessage(Handle<Value> value)
  {
     return ISmsBinaryMessage::Unwrap<ISmsBinaryMessage>(value.As<Object>())->_instance;
  }

  void InitISmsBinaryMessage(Handle<Object> exports)
  {
    ISmsBinaryMessage::Init(exports);
  }

  class SmsBinaryMessage : public WrapperBase
  {
  public:    
    static v8::Handle<v8::Value> Init(const Handle<Object> exports)
    {
      HandleScope scope;
      
      s_constructorTemplate = Persistent<FunctionTemplate>::New(FunctionTemplate::New(New));
      s_constructorTemplate->SetClassName(String::NewSymbol("SmsBinaryMessage"));
      s_constructorTemplate->InstanceTemplate()->SetInternalFieldCount(1);
      
            
      s_constructorTemplate->PrototypeTemplate()->Set(String::NewSymbol("getData"), FunctionTemplate::New(GetData)->GetFunction());
      s_constructorTemplate->PrototypeTemplate()->Set(String::NewSymbol("setData"), FunctionTemplate::New(SetData)->GetFunction());
      
                        
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("id"), IdGetter);
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("messageClass"), MessageClassGetter);
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("format"), FormatGetter, FormatSetter);
      
      Local<Function> constructor = s_constructorTemplate->GetFunction();


      exports->Set(String::NewSymbol("SmsBinaryMessage"), constructor);
      return scope.Close(Undefined());
    }


    virtual ::Platform::Object^ GetObjectInstance() const override
    {
      return _instance;
    }

  private:
    
    SmsBinaryMessage(::Windows::Devices::Sms::SmsBinaryMessage^ instance)
    {
      _instance = instance;
    }
    
    
    static v8::Handle<v8::Value> New(const v8::Arguments& args)
    {
      HandleScope scope;

      // in case the constructor was called without the new operator
      if (!s_constructorTemplate->HasInstance(args.This()))
      {
        if (args.Length() > 0)
        {
          std::unique_ptr<Handle<Value> []> constructorArgs(new Handle<Value>[args.Length()]);

          Handle<Value> *argsPtr = constructorArgs.get();
          for (int i = 0; i < args.Length(); i++)
          {
            argsPtr[i] = args[i];
          }

          return s_constructorTemplate->GetFunction()->CallAsConstructor(args.Length(), constructorArgs.get());
        }
        else
        {
          return s_constructorTemplate->GetFunction()->CallAsConstructor(args.Length(), nullptr);
        }
      }
      
      ::Windows::Devices::Sms::SmsBinaryMessage^ winRtInstance;


      if (args.Length() == 1 && OpaqueWrapper::IsOpaqueWrapper(args[0]) &&
        NodeRT::Utils::IsWinRtWrapperOf<::Windows::Devices::Sms::SmsBinaryMessage^>(args[0]))
      {
        try 
        {
          winRtInstance = (::Windows::Devices::Sms::SmsBinaryMessage^) NodeRT::Utils::GetObjectInstance(args[0]);
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else if (args.Length() == 0)
      {
        try
        {
          winRtInstance = ref new ::Windows::Devices::Sms::SmsBinaryMessage();
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Invalid arguments, no suitable constructor found")));
        return scope.Close(Undefined());
      }

      args.This()->SetHiddenValue(String::NewSymbol("__winRtInstance__"), True());

      SmsBinaryMessage *wrapperInstance = new SmsBinaryMessage(winRtInstance);
      wrapperInstance->Wrap(args.This());

      return args.This();
    }


  
    static Handle<Value> GetData(const v8::Arguments& args)
    {
      HandleScope scope;

      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Devices::Sms::SmsBinaryMessage^>(args.This()))
      {
        return scope.Close(Undefined());
      }

      SmsBinaryMessage *wrapper = SmsBinaryMessage::Unwrap<SmsBinaryMessage>(args.This());

      if (args.Length() == 0)
      {
        try
        {
          ::Platform::Array<unsigned char>^ result;
          result = wrapper->_instance->GetData();
          return scope.Close(NodeRT::Collections::ArrayWrapper<unsigned char>::CreateArrayWrapper(result, 
            [](unsigned char val) -> Handle<Value> {
              return Integer::New(val);
            },
            [](Handle<Value> value) -> bool {
              return value->IsInt32();
            },
            [](Handle<Value> value) -> unsigned char {
              return static_cast<unsigned char>(value->Int32Value());
            }
          ));
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else 
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Bad arguments: no suitable overload found")));
        return scope.Close(Undefined());
      }

      return scope.Close(Undefined());
    }
    static Handle<Value> SetData(const v8::Arguments& args)
    {
      HandleScope scope;

      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Devices::Sms::SmsBinaryMessage^>(args.This()))
      {
        return scope.Close(Undefined());
      }

      SmsBinaryMessage *wrapper = SmsBinaryMessage::Unwrap<SmsBinaryMessage>(args.This());

      if (args.Length() == 1
        && (NodeRT::Utils::IsWinRtWrapperOf<::Platform::Array<unsigned char>^>(args[0]) || args[0]->IsArray()))
      {
        try
        {
          ::Platform::Array<unsigned char>^ arg0 = 
            [] (v8::Handle<v8::Value> value) -> ::Platform::Array<unsigned char>^
            {
              if (value->IsArray())
              {
                return NodeRT::Collections::JsArrayToWinrtArray<unsigned char>(value.As<Array>(), 
                 [](Handle<Value> value) -> bool {
                   return value->IsInt32();
                 },
                 [](Handle<Value> value) -> unsigned char {
                   return static_cast<unsigned char>(value->Int32Value());
                 }
                );
              }
              else
              {
                return dynamic_cast<::Platform::Array<unsigned char>^>(NodeRT::Utils::GetObjectInstance(value));
              }
            } (args[0]);
          
          wrapper->_instance->SetData(arg0);
          return scope.Close(Undefined());   
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else 
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Bad arguments: no suitable overload found")));
        return scope.Close(Undefined());
      }

      return scope.Close(Undefined());
    }



    static Handle<Value> IdGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Devices::Sms::SmsBinaryMessage^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      SmsBinaryMessage *wrapper = SmsBinaryMessage::Unwrap<SmsBinaryMessage>(info.This());

      try 
      {
        unsigned int result = wrapper->_instance->Id;
        return scope.Close(Integer::New(result));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    
    static Handle<Value> MessageClassGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Devices::Sms::SmsBinaryMessage^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      SmsBinaryMessage *wrapper = SmsBinaryMessage::Unwrap<SmsBinaryMessage>(info.This());

      try 
      {
        ::Windows::Devices::Sms::SmsMessageClass result = wrapper->_instance->MessageClass;
        return scope.Close(Integer::New(static_cast<int>(result)));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    
    static Handle<Value> FormatGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Devices::Sms::SmsBinaryMessage^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      SmsBinaryMessage *wrapper = SmsBinaryMessage::Unwrap<SmsBinaryMessage>(info.This());

      try 
      {
        ::Windows::Devices::Sms::SmsDataFormat result = wrapper->_instance->Format;
        return scope.Close(Integer::New(static_cast<int>(result)));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    
    static void FormatSetter(Local<String> property, Local<Value> value, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!value->IsInt32())
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Value to set is of unexpected type")));
        return;
      }

      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Devices::Sms::SmsBinaryMessage^>(info.This()))
      {
        return;
      }

      SmsBinaryMessage *wrapper = SmsBinaryMessage::Unwrap<SmsBinaryMessage>(info.This());

      try 
      {
        
        ::Windows::Devices::Sms::SmsDataFormat winRtValue = static_cast<::Windows::Devices::Sms::SmsDataFormat>(value->Int32Value());

        wrapper->_instance->Format = winRtValue;
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
      }
    }
    


  private:
    ::Windows::Devices::Sms::SmsBinaryMessage^ _instance;
    static Persistent<FunctionTemplate> s_constructorTemplate;

    friend v8::Handle<v8::Value> WrapSmsBinaryMessage(::Windows::Devices::Sms::SmsBinaryMessage^ wintRtInstance);
    friend ::Windows::Devices::Sms::SmsBinaryMessage^ UnwrapSmsBinaryMessage(Handle<Value> value);
    friend bool IsSmsBinaryMessageWrapper(Handle<Value> value);
  };
  Persistent<FunctionTemplate> SmsBinaryMessage::s_constructorTemplate;

  v8::Handle<v8::Value> WrapSmsBinaryMessage(::Windows::Devices::Sms::SmsBinaryMessage^ winRtInstance)
  {
    HandleScope scope;

    if (winRtInstance == nullptr)
    {
      return scope.Close(Undefined());
    }

    Handle<Object> opaqueWrapper = CreateOpaqueWrapper(winRtInstance);
    Handle<Value> args[] = {opaqueWrapper};
    return scope.Close(SmsBinaryMessage::s_constructorTemplate->GetFunction()->NewInstance(_countof(args), args));
  }

  ::Windows::Devices::Sms::SmsBinaryMessage^ UnwrapSmsBinaryMessage(Handle<Value> value)
  {
     return SmsBinaryMessage::Unwrap<SmsBinaryMessage>(value.As<Object>())->_instance;
  }

  void InitSmsBinaryMessage(Handle<Object> exports)
  {
    SmsBinaryMessage::Init(exports);
  }

  class ISmsTextMessage : public WrapperBase
  {
  public:    
    static v8::Handle<v8::Value> Init(const Handle<Object> exports)
    {
      HandleScope scope;
      
      s_constructorTemplate = Persistent<FunctionTemplate>::New(FunctionTemplate::New(New));
      s_constructorTemplate->SetClassName(String::NewSymbol("ISmsTextMessage"));
      s_constructorTemplate->InstanceTemplate()->SetInternalFieldCount(1);
      
            
      s_constructorTemplate->PrototypeTemplate()->Set(String::NewSymbol("toBinaryMessages"), FunctionTemplate::New(ToBinaryMessages)->GetFunction());
      
                        
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("body"), BodyGetter, BodySetter);
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("encoding"), EncodingGetter, EncodingSetter);
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("from"), FromGetter, FromSetter);
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("partCount"), PartCountGetter);
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("partNumber"), PartNumberGetter);
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("partReferenceId"), PartReferenceIdGetter);
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("timestamp"), TimestampGetter);
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("to"), ToGetter, ToSetter);
      
      Local<Function> constructor = s_constructorTemplate->GetFunction();


      exports->Set(String::NewSymbol("ISmsTextMessage"), constructor);
      return scope.Close(Undefined());
    }


    virtual ::Platform::Object^ GetObjectInstance() const override
    {
      return _instance;
    }

  private:
    
    ISmsTextMessage(::Windows::Devices::Sms::ISmsTextMessage^ instance)
    {
      _instance = instance;
    }
    
    
    static v8::Handle<v8::Value> New(const v8::Arguments& args)
    {
      HandleScope scope;

      // in case the constructor was called without the new operator
      if (!s_constructorTemplate->HasInstance(args.This()))
      {
        if (args.Length() > 0)
        {
          std::unique_ptr<Handle<Value> []> constructorArgs(new Handle<Value>[args.Length()]);

          Handle<Value> *argsPtr = constructorArgs.get();
          for (int i = 0; i < args.Length(); i++)
          {
            argsPtr[i] = args[i];
          }

          return s_constructorTemplate->GetFunction()->CallAsConstructor(args.Length(), constructorArgs.get());
        }
        else
        {
          return s_constructorTemplate->GetFunction()->CallAsConstructor(args.Length(), nullptr);
        }
      }
      
      ::Windows::Devices::Sms::ISmsTextMessage^ winRtInstance;


      if (args.Length() == 1 && OpaqueWrapper::IsOpaqueWrapper(args[0]) &&
        NodeRT::Utils::IsWinRtWrapperOf<::Windows::Devices::Sms::ISmsTextMessage^>(args[0]))
      {
        try 
        {
          winRtInstance = (::Windows::Devices::Sms::ISmsTextMessage^) NodeRT::Utils::GetObjectInstance(args[0]);
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Invalid arguments, no suitable constructor found")));
        return scope.Close(Undefined());
      }

      args.This()->SetHiddenValue(String::NewSymbol("__winRtInstance__"), True());

      ISmsTextMessage *wrapperInstance = new ISmsTextMessage(winRtInstance);
      wrapperInstance->Wrap(args.This());

      return args.This();
    }


  
    static Handle<Value> ToBinaryMessages(const v8::Arguments& args)
    {
      HandleScope scope;

      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Devices::Sms::ISmsTextMessage^>(args.This()))
      {
        return scope.Close(Undefined());
      }

      ISmsTextMessage *wrapper = ISmsTextMessage::Unwrap<ISmsTextMessage>(args.This());

      if (args.Length() == 1
        && args[0]->IsInt32())
      {
        try
        {
          ::Windows::Devices::Sms::SmsDataFormat arg0 = static_cast<::Windows::Devices::Sms::SmsDataFormat>(args[0]->Int32Value());
          
          ::Windows::Foundation::Collections::IVectorView<::Windows::Devices::Sms::ISmsBinaryMessage^>^ result;
          result = wrapper->_instance->ToBinaryMessages(arg0);
          return scope.Close(NodeRT::Collections::VectorViewWrapper<::Windows::Devices::Sms::ISmsBinaryMessage^>::CreateVectorViewWrapper(result, 
            [](::Windows::Devices::Sms::ISmsBinaryMessage^ val) -> Handle<Value> {
              return WrapISmsBinaryMessage(val);
            },
            [](Handle<Value> value) -> bool {
              return NodeRT::Utils::IsWinRtWrapperOf<::Windows::Devices::Sms::ISmsBinaryMessage^>(value);
            },
            [](Handle<Value> value) -> ::Windows::Devices::Sms::ISmsBinaryMessage^ {
              return UnwrapISmsBinaryMessage(value);
            }
          ));
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else 
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Bad arguments: no suitable overload found")));
        return scope.Close(Undefined());
      }

      return scope.Close(Undefined());
    }



    static Handle<Value> BodyGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Devices::Sms::ISmsTextMessage^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      ISmsTextMessage *wrapper = ISmsTextMessage::Unwrap<ISmsTextMessage>(info.This());

      try 
      {
        Platform::String^ result = wrapper->_instance->Body;
        return scope.Close(NodeRT::Utils::NewString(result->Data()));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    
    static void BodySetter(Local<String> property, Local<Value> value, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!value->IsString())
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Value to set is of unexpected type")));
        return;
      }

      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Devices::Sms::ISmsTextMessage^>(info.This()))
      {
        return;
      }

      ISmsTextMessage *wrapper = ISmsTextMessage::Unwrap<ISmsTextMessage>(info.This());

      try 
      {
        
        Platform::String^ winRtValue = ref new Platform::String(NodeRT::Utils::StringToWchar(v8::String::Value(value)));

        wrapper->_instance->Body = winRtValue;
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
      }
    }
    
    static Handle<Value> EncodingGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Devices::Sms::ISmsTextMessage^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      ISmsTextMessage *wrapper = ISmsTextMessage::Unwrap<ISmsTextMessage>(info.This());

      try 
      {
        ::Windows::Devices::Sms::SmsEncoding result = wrapper->_instance->Encoding;
        return scope.Close(Integer::New(static_cast<int>(result)));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    
    static void EncodingSetter(Local<String> property, Local<Value> value, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!value->IsInt32())
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Value to set is of unexpected type")));
        return;
      }

      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Devices::Sms::ISmsTextMessage^>(info.This()))
      {
        return;
      }

      ISmsTextMessage *wrapper = ISmsTextMessage::Unwrap<ISmsTextMessage>(info.This());

      try 
      {
        
        ::Windows::Devices::Sms::SmsEncoding winRtValue = static_cast<::Windows::Devices::Sms::SmsEncoding>(value->Int32Value());

        wrapper->_instance->Encoding = winRtValue;
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
      }
    }
    
    static Handle<Value> FromGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Devices::Sms::ISmsTextMessage^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      ISmsTextMessage *wrapper = ISmsTextMessage::Unwrap<ISmsTextMessage>(info.This());

      try 
      {
        Platform::String^ result = wrapper->_instance->From;
        return scope.Close(NodeRT::Utils::NewString(result->Data()));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    
    static void FromSetter(Local<String> property, Local<Value> value, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!value->IsString())
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Value to set is of unexpected type")));
        return;
      }

      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Devices::Sms::ISmsTextMessage^>(info.This()))
      {
        return;
      }

      ISmsTextMessage *wrapper = ISmsTextMessage::Unwrap<ISmsTextMessage>(info.This());

      try 
      {
        
        Platform::String^ winRtValue = ref new Platform::String(NodeRT::Utils::StringToWchar(v8::String::Value(value)));

        wrapper->_instance->From = winRtValue;
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
      }
    }
    
    static Handle<Value> PartCountGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Devices::Sms::ISmsTextMessage^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      ISmsTextMessage *wrapper = ISmsTextMessage::Unwrap<ISmsTextMessage>(info.This());

      try 
      {
        unsigned int result = wrapper->_instance->PartCount;
        return scope.Close(Integer::New(result));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    
    static Handle<Value> PartNumberGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Devices::Sms::ISmsTextMessage^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      ISmsTextMessage *wrapper = ISmsTextMessage::Unwrap<ISmsTextMessage>(info.This());

      try 
      {
        unsigned int result = wrapper->_instance->PartNumber;
        return scope.Close(Integer::New(result));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    
    static Handle<Value> PartReferenceIdGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Devices::Sms::ISmsTextMessage^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      ISmsTextMessage *wrapper = ISmsTextMessage::Unwrap<ISmsTextMessage>(info.This());

      try 
      {
        unsigned int result = wrapper->_instance->PartReferenceId;
        return scope.Close(Integer::New(result));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    
    static Handle<Value> TimestampGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Devices::Sms::ISmsTextMessage^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      ISmsTextMessage *wrapper = ISmsTextMessage::Unwrap<ISmsTextMessage>(info.This());

      try 
      {
        ::Windows::Foundation::DateTime result = wrapper->_instance->Timestamp;
        return scope.Close(NodeRT::Utils::DateTimeToJS(result));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    
    static Handle<Value> ToGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Devices::Sms::ISmsTextMessage^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      ISmsTextMessage *wrapper = ISmsTextMessage::Unwrap<ISmsTextMessage>(info.This());

      try 
      {
        Platform::String^ result = wrapper->_instance->To;
        return scope.Close(NodeRT::Utils::NewString(result->Data()));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    
    static void ToSetter(Local<String> property, Local<Value> value, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!value->IsString())
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Value to set is of unexpected type")));
        return;
      }

      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Devices::Sms::ISmsTextMessage^>(info.This()))
      {
        return;
      }

      ISmsTextMessage *wrapper = ISmsTextMessage::Unwrap<ISmsTextMessage>(info.This());

      try 
      {
        
        Platform::String^ winRtValue = ref new Platform::String(NodeRT::Utils::StringToWchar(v8::String::Value(value)));

        wrapper->_instance->To = winRtValue;
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
      }
    }
    


  private:
    ::Windows::Devices::Sms::ISmsTextMessage^ _instance;
    static Persistent<FunctionTemplate> s_constructorTemplate;

    friend v8::Handle<v8::Value> WrapISmsTextMessage(::Windows::Devices::Sms::ISmsTextMessage^ wintRtInstance);
    friend ::Windows::Devices::Sms::ISmsTextMessage^ UnwrapISmsTextMessage(Handle<Value> value);
    friend bool IsISmsTextMessageWrapper(Handle<Value> value);
  };
  Persistent<FunctionTemplate> ISmsTextMessage::s_constructorTemplate;

  v8::Handle<v8::Value> WrapISmsTextMessage(::Windows::Devices::Sms::ISmsTextMessage^ winRtInstance)
  {
    HandleScope scope;

    if (winRtInstance == nullptr)
    {
      return scope.Close(Undefined());
    }

    Handle<Object> opaqueWrapper = CreateOpaqueWrapper(winRtInstance);
    Handle<Value> args[] = {opaqueWrapper};
    return scope.Close(ISmsTextMessage::s_constructorTemplate->GetFunction()->NewInstance(_countof(args), args));
  }

  ::Windows::Devices::Sms::ISmsTextMessage^ UnwrapISmsTextMessage(Handle<Value> value)
  {
     return ISmsTextMessage::Unwrap<ISmsTextMessage>(value.As<Object>())->_instance;
  }

  void InitISmsTextMessage(Handle<Object> exports)
  {
    ISmsTextMessage::Init(exports);
  }

  class SmsTextMessage : public WrapperBase
  {
  public:    
    static v8::Handle<v8::Value> Init(const Handle<Object> exports)
    {
      HandleScope scope;
      
      s_constructorTemplate = Persistent<FunctionTemplate>::New(FunctionTemplate::New(New));
      s_constructorTemplate->SetClassName(String::NewSymbol("SmsTextMessage"));
      s_constructorTemplate->InstanceTemplate()->SetInternalFieldCount(1);
      
            
      s_constructorTemplate->PrototypeTemplate()->Set(String::NewSymbol("toBinaryMessages"), FunctionTemplate::New(ToBinaryMessages)->GetFunction());
      
                        
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("to"), ToGetter, ToSetter);
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("from"), FromGetter, FromSetter);
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("encoding"), EncodingGetter, EncodingSetter);
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("body"), BodyGetter, BodySetter);
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("partCount"), PartCountGetter);
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("partNumber"), PartNumberGetter);
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("partReferenceId"), PartReferenceIdGetter);
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("timestamp"), TimestampGetter);
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("id"), IdGetter);
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("messageClass"), MessageClassGetter);
      
      Local<Function> constructor = s_constructorTemplate->GetFunction();

      constructor->Set(String::NewSymbol("fromBinaryMessage"), FunctionTemplate::New(FromBinaryMessage)->GetFunction());
      constructor->Set(String::NewSymbol("fromBinaryData"), FunctionTemplate::New(FromBinaryData)->GetFunction());

      exports->Set(String::NewSymbol("SmsTextMessage"), constructor);
      return scope.Close(Undefined());
    }


    virtual ::Platform::Object^ GetObjectInstance() const override
    {
      return _instance;
    }

  private:
    
    SmsTextMessage(::Windows::Devices::Sms::SmsTextMessage^ instance)
    {
      _instance = instance;
    }
    
    
    static v8::Handle<v8::Value> New(const v8::Arguments& args)
    {
      HandleScope scope;

      // in case the constructor was called without the new operator
      if (!s_constructorTemplate->HasInstance(args.This()))
      {
        if (args.Length() > 0)
        {
          std::unique_ptr<Handle<Value> []> constructorArgs(new Handle<Value>[args.Length()]);

          Handle<Value> *argsPtr = constructorArgs.get();
          for (int i = 0; i < args.Length(); i++)
          {
            argsPtr[i] = args[i];
          }

          return s_constructorTemplate->GetFunction()->CallAsConstructor(args.Length(), constructorArgs.get());
        }
        else
        {
          return s_constructorTemplate->GetFunction()->CallAsConstructor(args.Length(), nullptr);
        }
      }
      
      ::Windows::Devices::Sms::SmsTextMessage^ winRtInstance;


      if (args.Length() == 1 && OpaqueWrapper::IsOpaqueWrapper(args[0]) &&
        NodeRT::Utils::IsWinRtWrapperOf<::Windows::Devices::Sms::SmsTextMessage^>(args[0]))
      {
        try 
        {
          winRtInstance = (::Windows::Devices::Sms::SmsTextMessage^) NodeRT::Utils::GetObjectInstance(args[0]);
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else if (args.Length() == 0)
      {
        try
        {
          winRtInstance = ref new ::Windows::Devices::Sms::SmsTextMessage();
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Invalid arguments, no suitable constructor found")));
        return scope.Close(Undefined());
      }

      args.This()->SetHiddenValue(String::NewSymbol("__winRtInstance__"), True());

      SmsTextMessage *wrapperInstance = new SmsTextMessage(winRtInstance);
      wrapperInstance->Wrap(args.This());

      return args.This();
    }


  
    static Handle<Value> ToBinaryMessages(const v8::Arguments& args)
    {
      HandleScope scope;

      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Devices::Sms::SmsTextMessage^>(args.This()))
      {
        return scope.Close(Undefined());
      }

      SmsTextMessage *wrapper = SmsTextMessage::Unwrap<SmsTextMessage>(args.This());

      if (args.Length() == 1
        && args[0]->IsInt32())
      {
        try
        {
          ::Windows::Devices::Sms::SmsDataFormat arg0 = static_cast<::Windows::Devices::Sms::SmsDataFormat>(args[0]->Int32Value());
          
          ::Windows::Foundation::Collections::IVectorView<::Windows::Devices::Sms::ISmsBinaryMessage^>^ result;
          result = wrapper->_instance->ToBinaryMessages(arg0);
          return scope.Close(NodeRT::Collections::VectorViewWrapper<::Windows::Devices::Sms::ISmsBinaryMessage^>::CreateVectorViewWrapper(result, 
            [](::Windows::Devices::Sms::ISmsBinaryMessage^ val) -> Handle<Value> {
              return WrapISmsBinaryMessage(val);
            },
            [](Handle<Value> value) -> bool {
              return NodeRT::Utils::IsWinRtWrapperOf<::Windows::Devices::Sms::ISmsBinaryMessage^>(value);
            },
            [](Handle<Value> value) -> ::Windows::Devices::Sms::ISmsBinaryMessage^ {
              return UnwrapISmsBinaryMessage(value);
            }
          ));
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else 
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Bad arguments: no suitable overload found")));
        return scope.Close(Undefined());
      }

      return scope.Close(Undefined());
    }


    static Handle<Value> FromBinaryMessage(const v8::Arguments& args)
    {
      HandleScope scope;

      if (args.Length() == 1
        && NodeRT::Utils::IsWinRtWrapperOf<::Windows::Devices::Sms::SmsBinaryMessage^>(args[0]))
      {
        try
        {
          ::Windows::Devices::Sms::SmsBinaryMessage^ arg0 = UnwrapSmsBinaryMessage(args[0]);
          
          ::Windows::Devices::Sms::SmsTextMessage^ result;
          result = ::Windows::Devices::Sms::SmsTextMessage::FromBinaryMessage(arg0);
          return scope.Close(WrapSmsTextMessage(result));
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else 
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Bad arguments: no suitable overload found")));
        return scope.Close(Undefined());
      }

      return scope.Close(Undefined());
    }
    static Handle<Value> FromBinaryData(const v8::Arguments& args)
    {
      HandleScope scope;

      if (args.Length() == 2
        && args[0]->IsInt32()
        && (NodeRT::Utils::IsWinRtWrapperOf<::Platform::Array<unsigned char>^>(args[1]) || args[1]->IsArray()))
      {
        try
        {
          ::Windows::Devices::Sms::SmsDataFormat arg0 = static_cast<::Windows::Devices::Sms::SmsDataFormat>(args[0]->Int32Value());
          ::Platform::Array<unsigned char>^ arg1 = 
            [] (v8::Handle<v8::Value> value) -> ::Platform::Array<unsigned char>^
            {
              if (value->IsArray())
              {
                return NodeRT::Collections::JsArrayToWinrtArray<unsigned char>(value.As<Array>(), 
                 [](Handle<Value> value) -> bool {
                   return value->IsInt32();
                 },
                 [](Handle<Value> value) -> unsigned char {
                   return static_cast<unsigned char>(value->Int32Value());
                 }
                );
              }
              else
              {
                return dynamic_cast<::Platform::Array<unsigned char>^>(NodeRT::Utils::GetObjectInstance(value));
              }
            } (args[1]);
          
          ::Windows::Devices::Sms::SmsTextMessage^ result;
          result = ::Windows::Devices::Sms::SmsTextMessage::FromBinaryData(arg0, arg1);
          return scope.Close(WrapSmsTextMessage(result));
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else 
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Bad arguments: no suitable overload found")));
        return scope.Close(Undefined());
      }

      return scope.Close(Undefined());
    }

    static Handle<Value> ToGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Devices::Sms::SmsTextMessage^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      SmsTextMessage *wrapper = SmsTextMessage::Unwrap<SmsTextMessage>(info.This());

      try 
      {
        Platform::String^ result = wrapper->_instance->To;
        return scope.Close(NodeRT::Utils::NewString(result->Data()));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    
    static void ToSetter(Local<String> property, Local<Value> value, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!value->IsString())
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Value to set is of unexpected type")));
        return;
      }

      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Devices::Sms::SmsTextMessage^>(info.This()))
      {
        return;
      }

      SmsTextMessage *wrapper = SmsTextMessage::Unwrap<SmsTextMessage>(info.This());

      try 
      {
        
        Platform::String^ winRtValue = ref new Platform::String(NodeRT::Utils::StringToWchar(v8::String::Value(value)));

        wrapper->_instance->To = winRtValue;
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
      }
    }
    
    static Handle<Value> FromGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Devices::Sms::SmsTextMessage^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      SmsTextMessage *wrapper = SmsTextMessage::Unwrap<SmsTextMessage>(info.This());

      try 
      {
        Platform::String^ result = wrapper->_instance->From;
        return scope.Close(NodeRT::Utils::NewString(result->Data()));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    
    static void FromSetter(Local<String> property, Local<Value> value, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!value->IsString())
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Value to set is of unexpected type")));
        return;
      }

      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Devices::Sms::SmsTextMessage^>(info.This()))
      {
        return;
      }

      SmsTextMessage *wrapper = SmsTextMessage::Unwrap<SmsTextMessage>(info.This());

      try 
      {
        
        Platform::String^ winRtValue = ref new Platform::String(NodeRT::Utils::StringToWchar(v8::String::Value(value)));

        wrapper->_instance->From = winRtValue;
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
      }
    }
    
    static Handle<Value> EncodingGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Devices::Sms::SmsTextMessage^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      SmsTextMessage *wrapper = SmsTextMessage::Unwrap<SmsTextMessage>(info.This());

      try 
      {
        ::Windows::Devices::Sms::SmsEncoding result = wrapper->_instance->Encoding;
        return scope.Close(Integer::New(static_cast<int>(result)));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    
    static void EncodingSetter(Local<String> property, Local<Value> value, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!value->IsInt32())
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Value to set is of unexpected type")));
        return;
      }

      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Devices::Sms::SmsTextMessage^>(info.This()))
      {
        return;
      }

      SmsTextMessage *wrapper = SmsTextMessage::Unwrap<SmsTextMessage>(info.This());

      try 
      {
        
        ::Windows::Devices::Sms::SmsEncoding winRtValue = static_cast<::Windows::Devices::Sms::SmsEncoding>(value->Int32Value());

        wrapper->_instance->Encoding = winRtValue;
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
      }
    }
    
    static Handle<Value> BodyGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Devices::Sms::SmsTextMessage^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      SmsTextMessage *wrapper = SmsTextMessage::Unwrap<SmsTextMessage>(info.This());

      try 
      {
        Platform::String^ result = wrapper->_instance->Body;
        return scope.Close(NodeRT::Utils::NewString(result->Data()));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    
    static void BodySetter(Local<String> property, Local<Value> value, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!value->IsString())
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Value to set is of unexpected type")));
        return;
      }

      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Devices::Sms::SmsTextMessage^>(info.This()))
      {
        return;
      }

      SmsTextMessage *wrapper = SmsTextMessage::Unwrap<SmsTextMessage>(info.This());

      try 
      {
        
        Platform::String^ winRtValue = ref new Platform::String(NodeRT::Utils::StringToWchar(v8::String::Value(value)));

        wrapper->_instance->Body = winRtValue;
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
      }
    }
    
    static Handle<Value> PartCountGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Devices::Sms::SmsTextMessage^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      SmsTextMessage *wrapper = SmsTextMessage::Unwrap<SmsTextMessage>(info.This());

      try 
      {
        unsigned int result = wrapper->_instance->PartCount;
        return scope.Close(Integer::New(result));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    
    static Handle<Value> PartNumberGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Devices::Sms::SmsTextMessage^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      SmsTextMessage *wrapper = SmsTextMessage::Unwrap<SmsTextMessage>(info.This());

      try 
      {
        unsigned int result = wrapper->_instance->PartNumber;
        return scope.Close(Integer::New(result));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    
    static Handle<Value> PartReferenceIdGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Devices::Sms::SmsTextMessage^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      SmsTextMessage *wrapper = SmsTextMessage::Unwrap<SmsTextMessage>(info.This());

      try 
      {
        unsigned int result = wrapper->_instance->PartReferenceId;
        return scope.Close(Integer::New(result));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    
    static Handle<Value> TimestampGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Devices::Sms::SmsTextMessage^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      SmsTextMessage *wrapper = SmsTextMessage::Unwrap<SmsTextMessage>(info.This());

      try 
      {
        ::Windows::Foundation::DateTime result = wrapper->_instance->Timestamp;
        return scope.Close(NodeRT::Utils::DateTimeToJS(result));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    
    static Handle<Value> IdGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Devices::Sms::SmsTextMessage^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      SmsTextMessage *wrapper = SmsTextMessage::Unwrap<SmsTextMessage>(info.This());

      try 
      {
        unsigned int result = wrapper->_instance->Id;
        return scope.Close(Integer::New(result));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    
    static Handle<Value> MessageClassGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Devices::Sms::SmsTextMessage^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      SmsTextMessage *wrapper = SmsTextMessage::Unwrap<SmsTextMessage>(info.This());

      try 
      {
        ::Windows::Devices::Sms::SmsMessageClass result = wrapper->_instance->MessageClass;
        return scope.Close(Integer::New(static_cast<int>(result)));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    


  private:
    ::Windows::Devices::Sms::SmsTextMessage^ _instance;
    static Persistent<FunctionTemplate> s_constructorTemplate;

    friend v8::Handle<v8::Value> WrapSmsTextMessage(::Windows::Devices::Sms::SmsTextMessage^ wintRtInstance);
    friend ::Windows::Devices::Sms::SmsTextMessage^ UnwrapSmsTextMessage(Handle<Value> value);
    friend bool IsSmsTextMessageWrapper(Handle<Value> value);
  };
  Persistent<FunctionTemplate> SmsTextMessage::s_constructorTemplate;

  v8::Handle<v8::Value> WrapSmsTextMessage(::Windows::Devices::Sms::SmsTextMessage^ winRtInstance)
  {
    HandleScope scope;

    if (winRtInstance == nullptr)
    {
      return scope.Close(Undefined());
    }

    Handle<Object> opaqueWrapper = CreateOpaqueWrapper(winRtInstance);
    Handle<Value> args[] = {opaqueWrapper};
    return scope.Close(SmsTextMessage::s_constructorTemplate->GetFunction()->NewInstance(_countof(args), args));
  }

  ::Windows::Devices::Sms::SmsTextMessage^ UnwrapSmsTextMessage(Handle<Value> value)
  {
     return SmsTextMessage::Unwrap<SmsTextMessage>(value.As<Object>())->_instance;
  }

  void InitSmsTextMessage(Handle<Object> exports)
  {
    SmsTextMessage::Init(exports);
  }

  class DeleteSmsMessageOperation : public WrapperBase
  {
  public:    
    static v8::Handle<v8::Value> Init(const Handle<Object> exports)
    {
      HandleScope scope;
      
      s_constructorTemplate = Persistent<FunctionTemplate>::New(FunctionTemplate::New(New));
      s_constructorTemplate->SetClassName(String::NewSymbol("DeleteSmsMessageOperation"));
      s_constructorTemplate->InstanceTemplate()->SetInternalFieldCount(1);
      
            
      s_constructorTemplate->PrototypeTemplate()->Set(String::NewSymbol("getResults"), FunctionTemplate::New(GetResults)->GetFunction());
      s_constructorTemplate->PrototypeTemplate()->Set(String::NewSymbol("cancel"), FunctionTemplate::New(Cancel)->GetFunction());
      s_constructorTemplate->PrototypeTemplate()->Set(String::NewSymbol("close"), FunctionTemplate::New(Close)->GetFunction());
      
                        
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("completed"), CompletedGetter, CompletedSetter);
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("errorCode"), ErrorCodeGetter);
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("id"), IdGetter);
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("status"), StatusGetter);
      
      Local<Function> constructor = s_constructorTemplate->GetFunction();


      exports->Set(String::NewSymbol("DeleteSmsMessageOperation"), constructor);
      return scope.Close(Undefined());
    }


    virtual ::Platform::Object^ GetObjectInstance() const override
    {
      return _instance;
    }

  private:
    
    DeleteSmsMessageOperation(::Windows::Devices::Sms::DeleteSmsMessageOperation^ instance)
    {
      _instance = instance;
    }
    
    
    static v8::Handle<v8::Value> New(const v8::Arguments& args)
    {
      HandleScope scope;

      // in case the constructor was called without the new operator
      if (!s_constructorTemplate->HasInstance(args.This()))
      {
        if (args.Length() > 0)
        {
          std::unique_ptr<Handle<Value> []> constructorArgs(new Handle<Value>[args.Length()]);

          Handle<Value> *argsPtr = constructorArgs.get();
          for (int i = 0; i < args.Length(); i++)
          {
            argsPtr[i] = args[i];
          }

          return s_constructorTemplate->GetFunction()->CallAsConstructor(args.Length(), constructorArgs.get());
        }
        else
        {
          return s_constructorTemplate->GetFunction()->CallAsConstructor(args.Length(), nullptr);
        }
      }
      
      ::Windows::Devices::Sms::DeleteSmsMessageOperation^ winRtInstance;


      if (args.Length() == 1 && OpaqueWrapper::IsOpaqueWrapper(args[0]) &&
        NodeRT::Utils::IsWinRtWrapperOf<::Windows::Devices::Sms::DeleteSmsMessageOperation^>(args[0]))
      {
        try 
        {
          winRtInstance = (::Windows::Devices::Sms::DeleteSmsMessageOperation^) NodeRT::Utils::GetObjectInstance(args[0]);
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Invalid arguments, no suitable constructor found")));
        return scope.Close(Undefined());
      }

      args.This()->SetHiddenValue(String::NewSymbol("__winRtInstance__"), True());

      DeleteSmsMessageOperation *wrapperInstance = new DeleteSmsMessageOperation(winRtInstance);
      wrapperInstance->Wrap(args.This());

      return args.This();
    }


  
    static Handle<Value> GetResults(const v8::Arguments& args)
    {
      HandleScope scope;

      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Devices::Sms::DeleteSmsMessageOperation^>(args.This()))
      {
        return scope.Close(Undefined());
      }

      DeleteSmsMessageOperation *wrapper = DeleteSmsMessageOperation::Unwrap<DeleteSmsMessageOperation>(args.This());

      if (args.Length() == 0)
      {
        try
        {
          wrapper->_instance->GetResults();
          return scope.Close(Undefined());   
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else 
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Bad arguments: no suitable overload found")));
        return scope.Close(Undefined());
      }

      return scope.Close(Undefined());
    }
    static Handle<Value> Cancel(const v8::Arguments& args)
    {
      HandleScope scope;

      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Devices::Sms::DeleteSmsMessageOperation^>(args.This()))
      {
        return scope.Close(Undefined());
      }

      DeleteSmsMessageOperation *wrapper = DeleteSmsMessageOperation::Unwrap<DeleteSmsMessageOperation>(args.This());

      if (args.Length() == 0)
      {
        try
        {
          wrapper->_instance->Cancel();
          return scope.Close(Undefined());   
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else 
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Bad arguments: no suitable overload found")));
        return scope.Close(Undefined());
      }

      return scope.Close(Undefined());
    }
    static Handle<Value> Close(const v8::Arguments& args)
    {
      HandleScope scope;

      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Devices::Sms::DeleteSmsMessageOperation^>(args.This()))
      {
        return scope.Close(Undefined());
      }

      DeleteSmsMessageOperation *wrapper = DeleteSmsMessageOperation::Unwrap<DeleteSmsMessageOperation>(args.This());

      if (args.Length() == 0)
      {
        try
        {
          wrapper->_instance->Close();
          return scope.Close(Undefined());   
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else 
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Bad arguments: no suitable overload found")));
        return scope.Close(Undefined());
      }

      return scope.Close(Undefined());
    }



    static Handle<Value> CompletedGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Devices::Sms::DeleteSmsMessageOperation^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      DeleteSmsMessageOperation *wrapper = DeleteSmsMessageOperation::Unwrap<DeleteSmsMessageOperation>(info.This());

      try 
      {
        ::Windows::Foundation::AsyncActionCompletedHandler^ result = wrapper->_instance->Completed;
        return scope.Close(NodeRT::Utils::CreateExternalWinRTObject("Windows.Foundation", "AsyncActionCompletedHandler", result));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    
    static void CompletedSetter(Local<String> property, Local<Value> value, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Foundation::AsyncActionCompletedHandler^>(value))
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Value to set is of unexpected type")));
        return;
      }

      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Devices::Sms::DeleteSmsMessageOperation^>(info.This()))
      {
        return;
      }

      DeleteSmsMessageOperation *wrapper = DeleteSmsMessageOperation::Unwrap<DeleteSmsMessageOperation>(info.This());

      try 
      {
        
        ::Windows::Foundation::AsyncActionCompletedHandler^ winRtValue = dynamic_cast<::Windows::Foundation::AsyncActionCompletedHandler^>(NodeRT::Utils::GetObjectInstance(value));

        wrapper->_instance->Completed = winRtValue;
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
      }
    }
    
    static Handle<Value> ErrorCodeGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Devices::Sms::DeleteSmsMessageOperation^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      DeleteSmsMessageOperation *wrapper = DeleteSmsMessageOperation::Unwrap<DeleteSmsMessageOperation>(info.This());

      try 
      {
        ::Windows::Foundation::HResult result = wrapper->_instance->ErrorCode;
        return scope.Close(Integer::New(result.Value));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    
    static Handle<Value> IdGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Devices::Sms::DeleteSmsMessageOperation^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      DeleteSmsMessageOperation *wrapper = DeleteSmsMessageOperation::Unwrap<DeleteSmsMessageOperation>(info.This());

      try 
      {
        unsigned int result = wrapper->_instance->Id;
        return scope.Close(Integer::New(result));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    
    static Handle<Value> StatusGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Devices::Sms::DeleteSmsMessageOperation^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      DeleteSmsMessageOperation *wrapper = DeleteSmsMessageOperation::Unwrap<DeleteSmsMessageOperation>(info.This());

      try 
      {
        ::Windows::Foundation::AsyncStatus result = wrapper->_instance->Status;
        return scope.Close(Integer::New(static_cast<int>(result)));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    


  private:
    ::Windows::Devices::Sms::DeleteSmsMessageOperation^ _instance;
    static Persistent<FunctionTemplate> s_constructorTemplate;

    friend v8::Handle<v8::Value> WrapDeleteSmsMessageOperation(::Windows::Devices::Sms::DeleteSmsMessageOperation^ wintRtInstance);
    friend ::Windows::Devices::Sms::DeleteSmsMessageOperation^ UnwrapDeleteSmsMessageOperation(Handle<Value> value);
    friend bool IsDeleteSmsMessageOperationWrapper(Handle<Value> value);
  };
  Persistent<FunctionTemplate> DeleteSmsMessageOperation::s_constructorTemplate;

  v8::Handle<v8::Value> WrapDeleteSmsMessageOperation(::Windows::Devices::Sms::DeleteSmsMessageOperation^ winRtInstance)
  {
    HandleScope scope;

    if (winRtInstance == nullptr)
    {
      return scope.Close(Undefined());
    }

    Handle<Object> opaqueWrapper = CreateOpaqueWrapper(winRtInstance);
    Handle<Value> args[] = {opaqueWrapper};
    return scope.Close(DeleteSmsMessageOperation::s_constructorTemplate->GetFunction()->NewInstance(_countof(args), args));
  }

  ::Windows::Devices::Sms::DeleteSmsMessageOperation^ UnwrapDeleteSmsMessageOperation(Handle<Value> value)
  {
     return DeleteSmsMessageOperation::Unwrap<DeleteSmsMessageOperation>(value.As<Object>())->_instance;
  }

  void InitDeleteSmsMessageOperation(Handle<Object> exports)
  {
    DeleteSmsMessageOperation::Init(exports);
  }

  class DeleteSmsMessagesOperation : public WrapperBase
  {
  public:    
    static v8::Handle<v8::Value> Init(const Handle<Object> exports)
    {
      HandleScope scope;
      
      s_constructorTemplate = Persistent<FunctionTemplate>::New(FunctionTemplate::New(New));
      s_constructorTemplate->SetClassName(String::NewSymbol("DeleteSmsMessagesOperation"));
      s_constructorTemplate->InstanceTemplate()->SetInternalFieldCount(1);
      
            
      s_constructorTemplate->PrototypeTemplate()->Set(String::NewSymbol("getResults"), FunctionTemplate::New(GetResults)->GetFunction());
      s_constructorTemplate->PrototypeTemplate()->Set(String::NewSymbol("cancel"), FunctionTemplate::New(Cancel)->GetFunction());
      s_constructorTemplate->PrototypeTemplate()->Set(String::NewSymbol("close"), FunctionTemplate::New(Close)->GetFunction());
      
                        
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("completed"), CompletedGetter, CompletedSetter);
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("errorCode"), ErrorCodeGetter);
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("id"), IdGetter);
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("status"), StatusGetter);
      
      Local<Function> constructor = s_constructorTemplate->GetFunction();


      exports->Set(String::NewSymbol("DeleteSmsMessagesOperation"), constructor);
      return scope.Close(Undefined());
    }


    virtual ::Platform::Object^ GetObjectInstance() const override
    {
      return _instance;
    }

  private:
    
    DeleteSmsMessagesOperation(::Windows::Devices::Sms::DeleteSmsMessagesOperation^ instance)
    {
      _instance = instance;
    }
    
    
    static v8::Handle<v8::Value> New(const v8::Arguments& args)
    {
      HandleScope scope;

      // in case the constructor was called without the new operator
      if (!s_constructorTemplate->HasInstance(args.This()))
      {
        if (args.Length() > 0)
        {
          std::unique_ptr<Handle<Value> []> constructorArgs(new Handle<Value>[args.Length()]);

          Handle<Value> *argsPtr = constructorArgs.get();
          for (int i = 0; i < args.Length(); i++)
          {
            argsPtr[i] = args[i];
          }

          return s_constructorTemplate->GetFunction()->CallAsConstructor(args.Length(), constructorArgs.get());
        }
        else
        {
          return s_constructorTemplate->GetFunction()->CallAsConstructor(args.Length(), nullptr);
        }
      }
      
      ::Windows::Devices::Sms::DeleteSmsMessagesOperation^ winRtInstance;


      if (args.Length() == 1 && OpaqueWrapper::IsOpaqueWrapper(args[0]) &&
        NodeRT::Utils::IsWinRtWrapperOf<::Windows::Devices::Sms::DeleteSmsMessagesOperation^>(args[0]))
      {
        try 
        {
          winRtInstance = (::Windows::Devices::Sms::DeleteSmsMessagesOperation^) NodeRT::Utils::GetObjectInstance(args[0]);
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Invalid arguments, no suitable constructor found")));
        return scope.Close(Undefined());
      }

      args.This()->SetHiddenValue(String::NewSymbol("__winRtInstance__"), True());

      DeleteSmsMessagesOperation *wrapperInstance = new DeleteSmsMessagesOperation(winRtInstance);
      wrapperInstance->Wrap(args.This());

      return args.This();
    }


  
    static Handle<Value> GetResults(const v8::Arguments& args)
    {
      HandleScope scope;

      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Devices::Sms::DeleteSmsMessagesOperation^>(args.This()))
      {
        return scope.Close(Undefined());
      }

      DeleteSmsMessagesOperation *wrapper = DeleteSmsMessagesOperation::Unwrap<DeleteSmsMessagesOperation>(args.This());

      if (args.Length() == 0)
      {
        try
        {
          wrapper->_instance->GetResults();
          return scope.Close(Undefined());   
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else 
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Bad arguments: no suitable overload found")));
        return scope.Close(Undefined());
      }

      return scope.Close(Undefined());
    }
    static Handle<Value> Cancel(const v8::Arguments& args)
    {
      HandleScope scope;

      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Devices::Sms::DeleteSmsMessagesOperation^>(args.This()))
      {
        return scope.Close(Undefined());
      }

      DeleteSmsMessagesOperation *wrapper = DeleteSmsMessagesOperation::Unwrap<DeleteSmsMessagesOperation>(args.This());

      if (args.Length() == 0)
      {
        try
        {
          wrapper->_instance->Cancel();
          return scope.Close(Undefined());   
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else 
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Bad arguments: no suitable overload found")));
        return scope.Close(Undefined());
      }

      return scope.Close(Undefined());
    }
    static Handle<Value> Close(const v8::Arguments& args)
    {
      HandleScope scope;

      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Devices::Sms::DeleteSmsMessagesOperation^>(args.This()))
      {
        return scope.Close(Undefined());
      }

      DeleteSmsMessagesOperation *wrapper = DeleteSmsMessagesOperation::Unwrap<DeleteSmsMessagesOperation>(args.This());

      if (args.Length() == 0)
      {
        try
        {
          wrapper->_instance->Close();
          return scope.Close(Undefined());   
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else 
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Bad arguments: no suitable overload found")));
        return scope.Close(Undefined());
      }

      return scope.Close(Undefined());
    }



    static Handle<Value> CompletedGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Devices::Sms::DeleteSmsMessagesOperation^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      DeleteSmsMessagesOperation *wrapper = DeleteSmsMessagesOperation::Unwrap<DeleteSmsMessagesOperation>(info.This());

      try 
      {
        ::Windows::Foundation::AsyncActionCompletedHandler^ result = wrapper->_instance->Completed;
        return scope.Close(NodeRT::Utils::CreateExternalWinRTObject("Windows.Foundation", "AsyncActionCompletedHandler", result));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    
    static void CompletedSetter(Local<String> property, Local<Value> value, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Foundation::AsyncActionCompletedHandler^>(value))
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Value to set is of unexpected type")));
        return;
      }

      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Devices::Sms::DeleteSmsMessagesOperation^>(info.This()))
      {
        return;
      }

      DeleteSmsMessagesOperation *wrapper = DeleteSmsMessagesOperation::Unwrap<DeleteSmsMessagesOperation>(info.This());

      try 
      {
        
        ::Windows::Foundation::AsyncActionCompletedHandler^ winRtValue = dynamic_cast<::Windows::Foundation::AsyncActionCompletedHandler^>(NodeRT::Utils::GetObjectInstance(value));

        wrapper->_instance->Completed = winRtValue;
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
      }
    }
    
    static Handle<Value> ErrorCodeGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Devices::Sms::DeleteSmsMessagesOperation^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      DeleteSmsMessagesOperation *wrapper = DeleteSmsMessagesOperation::Unwrap<DeleteSmsMessagesOperation>(info.This());

      try 
      {
        ::Windows::Foundation::HResult result = wrapper->_instance->ErrorCode;
        return scope.Close(Integer::New(result.Value));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    
    static Handle<Value> IdGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Devices::Sms::DeleteSmsMessagesOperation^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      DeleteSmsMessagesOperation *wrapper = DeleteSmsMessagesOperation::Unwrap<DeleteSmsMessagesOperation>(info.This());

      try 
      {
        unsigned int result = wrapper->_instance->Id;
        return scope.Close(Integer::New(result));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    
    static Handle<Value> StatusGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Devices::Sms::DeleteSmsMessagesOperation^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      DeleteSmsMessagesOperation *wrapper = DeleteSmsMessagesOperation::Unwrap<DeleteSmsMessagesOperation>(info.This());

      try 
      {
        ::Windows::Foundation::AsyncStatus result = wrapper->_instance->Status;
        return scope.Close(Integer::New(static_cast<int>(result)));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    


  private:
    ::Windows::Devices::Sms::DeleteSmsMessagesOperation^ _instance;
    static Persistent<FunctionTemplate> s_constructorTemplate;

    friend v8::Handle<v8::Value> WrapDeleteSmsMessagesOperation(::Windows::Devices::Sms::DeleteSmsMessagesOperation^ wintRtInstance);
    friend ::Windows::Devices::Sms::DeleteSmsMessagesOperation^ UnwrapDeleteSmsMessagesOperation(Handle<Value> value);
    friend bool IsDeleteSmsMessagesOperationWrapper(Handle<Value> value);
  };
  Persistent<FunctionTemplate> DeleteSmsMessagesOperation::s_constructorTemplate;

  v8::Handle<v8::Value> WrapDeleteSmsMessagesOperation(::Windows::Devices::Sms::DeleteSmsMessagesOperation^ winRtInstance)
  {
    HandleScope scope;

    if (winRtInstance == nullptr)
    {
      return scope.Close(Undefined());
    }

    Handle<Object> opaqueWrapper = CreateOpaqueWrapper(winRtInstance);
    Handle<Value> args[] = {opaqueWrapper};
    return scope.Close(DeleteSmsMessagesOperation::s_constructorTemplate->GetFunction()->NewInstance(_countof(args), args));
  }

  ::Windows::Devices::Sms::DeleteSmsMessagesOperation^ UnwrapDeleteSmsMessagesOperation(Handle<Value> value)
  {
     return DeleteSmsMessagesOperation::Unwrap<DeleteSmsMessagesOperation>(value.As<Object>())->_instance;
  }

  void InitDeleteSmsMessagesOperation(Handle<Object> exports)
  {
    DeleteSmsMessagesOperation::Init(exports);
  }

  class GetSmsMessageOperation : public WrapperBase
  {
  public:    
    static v8::Handle<v8::Value> Init(const Handle<Object> exports)
    {
      HandleScope scope;
      
      s_constructorTemplate = Persistent<FunctionTemplate>::New(FunctionTemplate::New(New));
      s_constructorTemplate->SetClassName(String::NewSymbol("GetSmsMessageOperation"));
      s_constructorTemplate->InstanceTemplate()->SetInternalFieldCount(1);
      
            
      s_constructorTemplate->PrototypeTemplate()->Set(String::NewSymbol("getResults"), FunctionTemplate::New(GetResults)->GetFunction());
      s_constructorTemplate->PrototypeTemplate()->Set(String::NewSymbol("cancel"), FunctionTemplate::New(Cancel)->GetFunction());
      s_constructorTemplate->PrototypeTemplate()->Set(String::NewSymbol("close"), FunctionTemplate::New(Close)->GetFunction());
      
                        
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("completed"), CompletedGetter, CompletedSetter);
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("errorCode"), ErrorCodeGetter);
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("id"), IdGetter);
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("status"), StatusGetter);
      
      Local<Function> constructor = s_constructorTemplate->GetFunction();


      exports->Set(String::NewSymbol("GetSmsMessageOperation"), constructor);
      return scope.Close(Undefined());
    }


    virtual ::Platform::Object^ GetObjectInstance() const override
    {
      return _instance;
    }

  private:
    
    GetSmsMessageOperation(::Windows::Devices::Sms::GetSmsMessageOperation^ instance)
    {
      _instance = instance;
    }
    
    
    static v8::Handle<v8::Value> New(const v8::Arguments& args)
    {
      HandleScope scope;

      // in case the constructor was called without the new operator
      if (!s_constructorTemplate->HasInstance(args.This()))
      {
        if (args.Length() > 0)
        {
          std::unique_ptr<Handle<Value> []> constructorArgs(new Handle<Value>[args.Length()]);

          Handle<Value> *argsPtr = constructorArgs.get();
          for (int i = 0; i < args.Length(); i++)
          {
            argsPtr[i] = args[i];
          }

          return s_constructorTemplate->GetFunction()->CallAsConstructor(args.Length(), constructorArgs.get());
        }
        else
        {
          return s_constructorTemplate->GetFunction()->CallAsConstructor(args.Length(), nullptr);
        }
      }
      
      ::Windows::Devices::Sms::GetSmsMessageOperation^ winRtInstance;


      if (args.Length() == 1 && OpaqueWrapper::IsOpaqueWrapper(args[0]) &&
        NodeRT::Utils::IsWinRtWrapperOf<::Windows::Devices::Sms::GetSmsMessageOperation^>(args[0]))
      {
        try 
        {
          winRtInstance = (::Windows::Devices::Sms::GetSmsMessageOperation^) NodeRT::Utils::GetObjectInstance(args[0]);
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Invalid arguments, no suitable constructor found")));
        return scope.Close(Undefined());
      }

      args.This()->SetHiddenValue(String::NewSymbol("__winRtInstance__"), True());

      GetSmsMessageOperation *wrapperInstance = new GetSmsMessageOperation(winRtInstance);
      wrapperInstance->Wrap(args.This());

      return args.This();
    }


  
    static Handle<Value> GetResults(const v8::Arguments& args)
    {
      HandleScope scope;

      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Devices::Sms::GetSmsMessageOperation^>(args.This()))
      {
        return scope.Close(Undefined());
      }

      GetSmsMessageOperation *wrapper = GetSmsMessageOperation::Unwrap<GetSmsMessageOperation>(args.This());

      if (args.Length() == 0)
      {
        try
        {
          ::Windows::Devices::Sms::ISmsMessage^ result;
          result = wrapper->_instance->GetResults();
          return scope.Close(WrapISmsMessage(result));
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else 
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Bad arguments: no suitable overload found")));
        return scope.Close(Undefined());
      }

      return scope.Close(Undefined());
    }
    static Handle<Value> Cancel(const v8::Arguments& args)
    {
      HandleScope scope;

      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Devices::Sms::GetSmsMessageOperation^>(args.This()))
      {
        return scope.Close(Undefined());
      }

      GetSmsMessageOperation *wrapper = GetSmsMessageOperation::Unwrap<GetSmsMessageOperation>(args.This());

      if (args.Length() == 0)
      {
        try
        {
          wrapper->_instance->Cancel();
          return scope.Close(Undefined());   
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else 
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Bad arguments: no suitable overload found")));
        return scope.Close(Undefined());
      }

      return scope.Close(Undefined());
    }
    static Handle<Value> Close(const v8::Arguments& args)
    {
      HandleScope scope;

      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Devices::Sms::GetSmsMessageOperation^>(args.This()))
      {
        return scope.Close(Undefined());
      }

      GetSmsMessageOperation *wrapper = GetSmsMessageOperation::Unwrap<GetSmsMessageOperation>(args.This());

      if (args.Length() == 0)
      {
        try
        {
          wrapper->_instance->Close();
          return scope.Close(Undefined());   
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else 
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Bad arguments: no suitable overload found")));
        return scope.Close(Undefined());
      }

      return scope.Close(Undefined());
    }



    static Handle<Value> CompletedGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Devices::Sms::GetSmsMessageOperation^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      GetSmsMessageOperation *wrapper = GetSmsMessageOperation::Unwrap<GetSmsMessageOperation>(info.This());

      try 
      {
        ::Windows::Foundation::AsyncOperationCompletedHandler<::Windows::Devices::Sms::ISmsMessage^>^ result = wrapper->_instance->Completed;
        return scope.Close(NodeRT::Utils::CreateExternalWinRTObject("Windows.Foundation", "AsyncOperationCompletedHandler`1", result));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    
    static void CompletedSetter(Local<String> property, Local<Value> value, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Foundation::AsyncOperationCompletedHandler<::Windows::Devices::Sms::ISmsMessage^>^>(value))
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Value to set is of unexpected type")));
        return;
      }

      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Devices::Sms::GetSmsMessageOperation^>(info.This()))
      {
        return;
      }

      GetSmsMessageOperation *wrapper = GetSmsMessageOperation::Unwrap<GetSmsMessageOperation>(info.This());

      try 
      {
        
        ::Windows::Foundation::AsyncOperationCompletedHandler<::Windows::Devices::Sms::ISmsMessage^>^ winRtValue = dynamic_cast<::Windows::Foundation::AsyncOperationCompletedHandler<::Windows::Devices::Sms::ISmsMessage^>^>(NodeRT::Utils::GetObjectInstance(value));

        wrapper->_instance->Completed = winRtValue;
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
      }
    }
    
    static Handle<Value> ErrorCodeGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Devices::Sms::GetSmsMessageOperation^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      GetSmsMessageOperation *wrapper = GetSmsMessageOperation::Unwrap<GetSmsMessageOperation>(info.This());

      try 
      {
        ::Windows::Foundation::HResult result = wrapper->_instance->ErrorCode;
        return scope.Close(Integer::New(result.Value));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    
    static Handle<Value> IdGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Devices::Sms::GetSmsMessageOperation^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      GetSmsMessageOperation *wrapper = GetSmsMessageOperation::Unwrap<GetSmsMessageOperation>(info.This());

      try 
      {
        unsigned int result = wrapper->_instance->Id;
        return scope.Close(Integer::New(result));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    
    static Handle<Value> StatusGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Devices::Sms::GetSmsMessageOperation^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      GetSmsMessageOperation *wrapper = GetSmsMessageOperation::Unwrap<GetSmsMessageOperation>(info.This());

      try 
      {
        ::Windows::Foundation::AsyncStatus result = wrapper->_instance->Status;
        return scope.Close(Integer::New(static_cast<int>(result)));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    


  private:
    ::Windows::Devices::Sms::GetSmsMessageOperation^ _instance;
    static Persistent<FunctionTemplate> s_constructorTemplate;

    friend v8::Handle<v8::Value> WrapGetSmsMessageOperation(::Windows::Devices::Sms::GetSmsMessageOperation^ wintRtInstance);
    friend ::Windows::Devices::Sms::GetSmsMessageOperation^ UnwrapGetSmsMessageOperation(Handle<Value> value);
    friend bool IsGetSmsMessageOperationWrapper(Handle<Value> value);
  };
  Persistent<FunctionTemplate> GetSmsMessageOperation::s_constructorTemplate;

  v8::Handle<v8::Value> WrapGetSmsMessageOperation(::Windows::Devices::Sms::GetSmsMessageOperation^ winRtInstance)
  {
    HandleScope scope;

    if (winRtInstance == nullptr)
    {
      return scope.Close(Undefined());
    }

    Handle<Object> opaqueWrapper = CreateOpaqueWrapper(winRtInstance);
    Handle<Value> args[] = {opaqueWrapper};
    return scope.Close(GetSmsMessageOperation::s_constructorTemplate->GetFunction()->NewInstance(_countof(args), args));
  }

  ::Windows::Devices::Sms::GetSmsMessageOperation^ UnwrapGetSmsMessageOperation(Handle<Value> value)
  {
     return GetSmsMessageOperation::Unwrap<GetSmsMessageOperation>(value.As<Object>())->_instance;
  }

  void InitGetSmsMessageOperation(Handle<Object> exports)
  {
    GetSmsMessageOperation::Init(exports);
  }

  class GetSmsMessagesOperation : public WrapperBase
  {
  public:    
    static v8::Handle<v8::Value> Init(const Handle<Object> exports)
    {
      HandleScope scope;
      
      s_constructorTemplate = Persistent<FunctionTemplate>::New(FunctionTemplate::New(New));
      s_constructorTemplate->SetClassName(String::NewSymbol("GetSmsMessagesOperation"));
      s_constructorTemplate->InstanceTemplate()->SetInternalFieldCount(1);
      
            
      s_constructorTemplate->PrototypeTemplate()->Set(String::NewSymbol("getResults"), FunctionTemplate::New(GetResults)->GetFunction());
      s_constructorTemplate->PrototypeTemplate()->Set(String::NewSymbol("cancel"), FunctionTemplate::New(Cancel)->GetFunction());
      s_constructorTemplate->PrototypeTemplate()->Set(String::NewSymbol("close"), FunctionTemplate::New(Close)->GetFunction());
      
                        
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("errorCode"), ErrorCodeGetter);
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("id"), IdGetter);
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("status"), StatusGetter);
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("progress"), ProgressGetter, ProgressSetter);
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("completed"), CompletedGetter, CompletedSetter);
      
      Local<Function> constructor = s_constructorTemplate->GetFunction();


      exports->Set(String::NewSymbol("GetSmsMessagesOperation"), constructor);
      return scope.Close(Undefined());
    }


    virtual ::Platform::Object^ GetObjectInstance() const override
    {
      return _instance;
    }

  private:
    
    GetSmsMessagesOperation(::Windows::Devices::Sms::GetSmsMessagesOperation^ instance)
    {
      _instance = instance;
    }
    
    
    static v8::Handle<v8::Value> New(const v8::Arguments& args)
    {
      HandleScope scope;

      // in case the constructor was called without the new operator
      if (!s_constructorTemplate->HasInstance(args.This()))
      {
        if (args.Length() > 0)
        {
          std::unique_ptr<Handle<Value> []> constructorArgs(new Handle<Value>[args.Length()]);

          Handle<Value> *argsPtr = constructorArgs.get();
          for (int i = 0; i < args.Length(); i++)
          {
            argsPtr[i] = args[i];
          }

          return s_constructorTemplate->GetFunction()->CallAsConstructor(args.Length(), constructorArgs.get());
        }
        else
        {
          return s_constructorTemplate->GetFunction()->CallAsConstructor(args.Length(), nullptr);
        }
      }
      
      ::Windows::Devices::Sms::GetSmsMessagesOperation^ winRtInstance;


      if (args.Length() == 1 && OpaqueWrapper::IsOpaqueWrapper(args[0]) &&
        NodeRT::Utils::IsWinRtWrapperOf<::Windows::Devices::Sms::GetSmsMessagesOperation^>(args[0]))
      {
        try 
        {
          winRtInstance = (::Windows::Devices::Sms::GetSmsMessagesOperation^) NodeRT::Utils::GetObjectInstance(args[0]);
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Invalid arguments, no suitable constructor found")));
        return scope.Close(Undefined());
      }

      args.This()->SetHiddenValue(String::NewSymbol("__winRtInstance__"), True());

      GetSmsMessagesOperation *wrapperInstance = new GetSmsMessagesOperation(winRtInstance);
      wrapperInstance->Wrap(args.This());

      return args.This();
    }


  
    static Handle<Value> GetResults(const v8::Arguments& args)
    {
      HandleScope scope;

      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Devices::Sms::GetSmsMessagesOperation^>(args.This()))
      {
        return scope.Close(Undefined());
      }

      GetSmsMessagesOperation *wrapper = GetSmsMessagesOperation::Unwrap<GetSmsMessagesOperation>(args.This());

      if (args.Length() == 0)
      {
        try
        {
          ::Windows::Foundation::Collections::IVectorView<::Windows::Devices::Sms::ISmsMessage^>^ result;
          result = wrapper->_instance->GetResults();
          return scope.Close(NodeRT::Collections::VectorViewWrapper<::Windows::Devices::Sms::ISmsMessage^>::CreateVectorViewWrapper(result, 
            [](::Windows::Devices::Sms::ISmsMessage^ val) -> Handle<Value> {
              return WrapISmsMessage(val);
            },
            [](Handle<Value> value) -> bool {
              return NodeRT::Utils::IsWinRtWrapperOf<::Windows::Devices::Sms::ISmsMessage^>(value);
            },
            [](Handle<Value> value) -> ::Windows::Devices::Sms::ISmsMessage^ {
              return UnwrapISmsMessage(value);
            }
          ));
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else 
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Bad arguments: no suitable overload found")));
        return scope.Close(Undefined());
      }

      return scope.Close(Undefined());
    }
    static Handle<Value> Cancel(const v8::Arguments& args)
    {
      HandleScope scope;

      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Devices::Sms::GetSmsMessagesOperation^>(args.This()))
      {
        return scope.Close(Undefined());
      }

      GetSmsMessagesOperation *wrapper = GetSmsMessagesOperation::Unwrap<GetSmsMessagesOperation>(args.This());

      if (args.Length() == 0)
      {
        try
        {
          wrapper->_instance->Cancel();
          return scope.Close(Undefined());   
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else 
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Bad arguments: no suitable overload found")));
        return scope.Close(Undefined());
      }

      return scope.Close(Undefined());
    }
    static Handle<Value> Close(const v8::Arguments& args)
    {
      HandleScope scope;

      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Devices::Sms::GetSmsMessagesOperation^>(args.This()))
      {
        return scope.Close(Undefined());
      }

      GetSmsMessagesOperation *wrapper = GetSmsMessagesOperation::Unwrap<GetSmsMessagesOperation>(args.This());

      if (args.Length() == 0)
      {
        try
        {
          wrapper->_instance->Close();
          return scope.Close(Undefined());   
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else 
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Bad arguments: no suitable overload found")));
        return scope.Close(Undefined());
      }

      return scope.Close(Undefined());
    }



    static Handle<Value> ErrorCodeGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Devices::Sms::GetSmsMessagesOperation^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      GetSmsMessagesOperation *wrapper = GetSmsMessagesOperation::Unwrap<GetSmsMessagesOperation>(info.This());

      try 
      {
        ::Windows::Foundation::HResult result = wrapper->_instance->ErrorCode;
        return scope.Close(Integer::New(result.Value));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    
    static Handle<Value> IdGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Devices::Sms::GetSmsMessagesOperation^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      GetSmsMessagesOperation *wrapper = GetSmsMessagesOperation::Unwrap<GetSmsMessagesOperation>(info.This());

      try 
      {
        unsigned int result = wrapper->_instance->Id;
        return scope.Close(Integer::New(result));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    
    static Handle<Value> StatusGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Devices::Sms::GetSmsMessagesOperation^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      GetSmsMessagesOperation *wrapper = GetSmsMessagesOperation::Unwrap<GetSmsMessagesOperation>(info.This());

      try 
      {
        ::Windows::Foundation::AsyncStatus result = wrapper->_instance->Status;
        return scope.Close(Integer::New(static_cast<int>(result)));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    
    static Handle<Value> ProgressGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Devices::Sms::GetSmsMessagesOperation^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      GetSmsMessagesOperation *wrapper = GetSmsMessagesOperation::Unwrap<GetSmsMessagesOperation>(info.This());

      try 
      {
        ::Windows::Foundation::AsyncOperationProgressHandler<::Windows::Foundation::Collections::IVectorView<::Windows::Devices::Sms::ISmsMessage^>^, int>^ result = wrapper->_instance->Progress;
        return scope.Close(NodeRT::Utils::CreateExternalWinRTObject("Windows.Foundation", "AsyncOperationProgressHandler`2", result));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    
    static void ProgressSetter(Local<String> property, Local<Value> value, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Foundation::AsyncOperationProgressHandler<::Windows::Foundation::Collections::IVectorView<::Windows::Devices::Sms::ISmsMessage^>^, int>^>(value))
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Value to set is of unexpected type")));
        return;
      }

      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Devices::Sms::GetSmsMessagesOperation^>(info.This()))
      {
        return;
      }

      GetSmsMessagesOperation *wrapper = GetSmsMessagesOperation::Unwrap<GetSmsMessagesOperation>(info.This());

      try 
      {
        
        ::Windows::Foundation::AsyncOperationProgressHandler<::Windows::Foundation::Collections::IVectorView<::Windows::Devices::Sms::ISmsMessage^>^, int>^ winRtValue = dynamic_cast<::Windows::Foundation::AsyncOperationProgressHandler<::Windows::Foundation::Collections::IVectorView<::Windows::Devices::Sms::ISmsMessage^>^, int>^>(NodeRT::Utils::GetObjectInstance(value));

        wrapper->_instance->Progress = winRtValue;
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
      }
    }
    
    static Handle<Value> CompletedGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Devices::Sms::GetSmsMessagesOperation^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      GetSmsMessagesOperation *wrapper = GetSmsMessagesOperation::Unwrap<GetSmsMessagesOperation>(info.This());

      try 
      {
        ::Windows::Foundation::AsyncOperationWithProgressCompletedHandler<::Windows::Foundation::Collections::IVectorView<::Windows::Devices::Sms::ISmsMessage^>^, int>^ result = wrapper->_instance->Completed;
        return scope.Close(NodeRT::Utils::CreateExternalWinRTObject("Windows.Foundation", "AsyncOperationWithProgressCompletedHandler`2", result));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    
    static void CompletedSetter(Local<String> property, Local<Value> value, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Foundation::AsyncOperationWithProgressCompletedHandler<::Windows::Foundation::Collections::IVectorView<::Windows::Devices::Sms::ISmsMessage^>^, int>^>(value))
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Value to set is of unexpected type")));
        return;
      }

      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Devices::Sms::GetSmsMessagesOperation^>(info.This()))
      {
        return;
      }

      GetSmsMessagesOperation *wrapper = GetSmsMessagesOperation::Unwrap<GetSmsMessagesOperation>(info.This());

      try 
      {
        
        ::Windows::Foundation::AsyncOperationWithProgressCompletedHandler<::Windows::Foundation::Collections::IVectorView<::Windows::Devices::Sms::ISmsMessage^>^, int>^ winRtValue = dynamic_cast<::Windows::Foundation::AsyncOperationWithProgressCompletedHandler<::Windows::Foundation::Collections::IVectorView<::Windows::Devices::Sms::ISmsMessage^>^, int>^>(NodeRT::Utils::GetObjectInstance(value));

        wrapper->_instance->Completed = winRtValue;
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
      }
    }
    


  private:
    ::Windows::Devices::Sms::GetSmsMessagesOperation^ _instance;
    static Persistent<FunctionTemplate> s_constructorTemplate;

    friend v8::Handle<v8::Value> WrapGetSmsMessagesOperation(::Windows::Devices::Sms::GetSmsMessagesOperation^ wintRtInstance);
    friend ::Windows::Devices::Sms::GetSmsMessagesOperation^ UnwrapGetSmsMessagesOperation(Handle<Value> value);
    friend bool IsGetSmsMessagesOperationWrapper(Handle<Value> value);
  };
  Persistent<FunctionTemplate> GetSmsMessagesOperation::s_constructorTemplate;

  v8::Handle<v8::Value> WrapGetSmsMessagesOperation(::Windows::Devices::Sms::GetSmsMessagesOperation^ winRtInstance)
  {
    HandleScope scope;

    if (winRtInstance == nullptr)
    {
      return scope.Close(Undefined());
    }

    Handle<Object> opaqueWrapper = CreateOpaqueWrapper(winRtInstance);
    Handle<Value> args[] = {opaqueWrapper};
    return scope.Close(GetSmsMessagesOperation::s_constructorTemplate->GetFunction()->NewInstance(_countof(args), args));
  }

  ::Windows::Devices::Sms::GetSmsMessagesOperation^ UnwrapGetSmsMessagesOperation(Handle<Value> value)
  {
     return GetSmsMessagesOperation::Unwrap<GetSmsMessagesOperation>(value.As<Object>())->_instance;
  }

  void InitGetSmsMessagesOperation(Handle<Object> exports)
  {
    GetSmsMessagesOperation::Init(exports);
  }

  class SmsDeviceMessageStore : public WrapperBase
  {
  public:    
    static v8::Handle<v8::Value> Init(const Handle<Object> exports)
    {
      HandleScope scope;
      
      s_constructorTemplate = Persistent<FunctionTemplate>::New(FunctionTemplate::New(New));
      s_constructorTemplate->SetClassName(String::NewSymbol("SmsDeviceMessageStore"));
      s_constructorTemplate->InstanceTemplate()->SetInternalFieldCount(1);
      
      Handle<Value> asyncSymbol = String::NewSymbol("__winRtAsync__");
      Handle<Function> func;
                  
      func = FunctionTemplate::New(DeleteMessageAsync)->GetFunction();
      func->Set(asyncSymbol, True(), PropertyAttribute::DontEnum);
      s_constructorTemplate->PrototypeTemplate()->Set(String::NewSymbol("deleteMessageAsync"), func);
      func = FunctionTemplate::New(DeleteMessagesAsync)->GetFunction();
      func->Set(asyncSymbol, True(), PropertyAttribute::DontEnum);
      s_constructorTemplate->PrototypeTemplate()->Set(String::NewSymbol("deleteMessagesAsync"), func);
      func = FunctionTemplate::New(GetMessageAsync)->GetFunction();
      func->Set(asyncSymbol, True(), PropertyAttribute::DontEnum);
      s_constructorTemplate->PrototypeTemplate()->Set(String::NewSymbol("getMessageAsync"), func);
      func = FunctionTemplate::New(GetMessagesAsync)->GetFunction();
      func->Set(asyncSymbol, True(), PropertyAttribute::DontEnum);
      s_constructorTemplate->PrototypeTemplate()->Set(String::NewSymbol("getMessagesAsync"), func);
      
                  
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("maxMessages"), MaxMessagesGetter);
      
      Local<Function> constructor = s_constructorTemplate->GetFunction();


      exports->Set(String::NewSymbol("SmsDeviceMessageStore"), constructor);
      return scope.Close(Undefined());
    }


    virtual ::Platform::Object^ GetObjectInstance() const override
    {
      return _instance;
    }

  private:
    
    SmsDeviceMessageStore(::Windows::Devices::Sms::SmsDeviceMessageStore^ instance)
    {
      _instance = instance;
    }
    
    
    static v8::Handle<v8::Value> New(const v8::Arguments& args)
    {
      HandleScope scope;

      // in case the constructor was called without the new operator
      if (!s_constructorTemplate->HasInstance(args.This()))
      {
        if (args.Length() > 0)
        {
          std::unique_ptr<Handle<Value> []> constructorArgs(new Handle<Value>[args.Length()]);

          Handle<Value> *argsPtr = constructorArgs.get();
          for (int i = 0; i < args.Length(); i++)
          {
            argsPtr[i] = args[i];
          }

          return s_constructorTemplate->GetFunction()->CallAsConstructor(args.Length(), constructorArgs.get());
        }
        else
        {
          return s_constructorTemplate->GetFunction()->CallAsConstructor(args.Length(), nullptr);
        }
      }
      
      ::Windows::Devices::Sms::SmsDeviceMessageStore^ winRtInstance;


      if (args.Length() == 1 && OpaqueWrapper::IsOpaqueWrapper(args[0]) &&
        NodeRT::Utils::IsWinRtWrapperOf<::Windows::Devices::Sms::SmsDeviceMessageStore^>(args[0]))
      {
        try 
        {
          winRtInstance = (::Windows::Devices::Sms::SmsDeviceMessageStore^) NodeRT::Utils::GetObjectInstance(args[0]);
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Invalid arguments, no suitable constructor found")));
        return scope.Close(Undefined());
      }

      args.This()->SetHiddenValue(String::NewSymbol("__winRtInstance__"), True());

      SmsDeviceMessageStore *wrapperInstance = new SmsDeviceMessageStore(winRtInstance);
      wrapperInstance->Wrap(args.This());

      return args.This();
    }


    static Handle<Value> DeleteMessageAsync(const v8::Arguments& args)
    {
      HandleScope scope;

      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Devices::Sms::SmsDeviceMessageStore^>(args.This()))
      {
        return scope.Close(Undefined());
      }

      if (args.Length() == 0 || !args[args.Length() -1]->IsFunction())
      {
          ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Bad arguments: No callback was given")));
          return scope.Close(Undefined());
      }

      SmsDeviceMessageStore *wrapper = SmsDeviceMessageStore::Unwrap<SmsDeviceMessageStore>(args.This());

      ::Windows::Foundation::IAsyncAction^ op;
    

      if (args.Length() == 2
        && args[0]->IsUint32())
      {
        try
        {
          unsigned int arg0 = static_cast<unsigned int>(args[0]->IntegerValue());
          
          op = wrapper->_instance->DeleteMessageAsync(arg0);
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else 
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Bad arguments: no suitable overload found")));
        return scope.Close(Undefined());
      }
    
      auto opTask = create_task(op);
      uv_async_t* asyncToken = NodeUtils::Async::GetAsyncToken(args[args.Length() -1].As<Function>());

      opTask.then( [asyncToken] (task<void> t) 
      {	
        try
        {
          t.get();
          NodeUtils::Async::RunCallbackOnMain(asyncToken, [](NodeUtils::InvokeCallbackDelegate invokeCallback) {


            Handle<Value> args[] = {Undefined()};

            invokeCallback(_countof(args), args);
          });
        }
        catch (Platform::Exception^ exception)
        {
          NodeUtils::Async::RunCallbackOnMain(asyncToken, [exception](NodeUtils::InvokeCallbackDelegate invokeCallback) {
             
            Handle<Value> error = NodeRT::Utils::WinRtExceptionToJsError(exception);
        
            Handle<Value> args[] = {error};
            invokeCallback(_countof(args), args);
          });
        }  		
      });

      return scope.Close(Undefined());
    }
    static Handle<Value> DeleteMessagesAsync(const v8::Arguments& args)
    {
      HandleScope scope;

      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Devices::Sms::SmsDeviceMessageStore^>(args.This()))
      {
        return scope.Close(Undefined());
      }

      if (args.Length() == 0 || !args[args.Length() -1]->IsFunction())
      {
          ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Bad arguments: No callback was given")));
          return scope.Close(Undefined());
      }

      SmsDeviceMessageStore *wrapper = SmsDeviceMessageStore::Unwrap<SmsDeviceMessageStore>(args.This());

      ::Windows::Foundation::IAsyncAction^ op;
    

      if (args.Length() == 2
        && args[0]->IsInt32())
      {
        try
        {
          ::Windows::Devices::Sms::SmsMessageFilter arg0 = static_cast<::Windows::Devices::Sms::SmsMessageFilter>(args[0]->Int32Value());
          
          op = wrapper->_instance->DeleteMessagesAsync(arg0);
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else 
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Bad arguments: no suitable overload found")));
        return scope.Close(Undefined());
      }
    
      auto opTask = create_task(op);
      uv_async_t* asyncToken = NodeUtils::Async::GetAsyncToken(args[args.Length() -1].As<Function>());

      opTask.then( [asyncToken] (task<void> t) 
      {	
        try
        {
          t.get();
          NodeUtils::Async::RunCallbackOnMain(asyncToken, [](NodeUtils::InvokeCallbackDelegate invokeCallback) {


            Handle<Value> args[] = {Undefined()};

            invokeCallback(_countof(args), args);
          });
        }
        catch (Platform::Exception^ exception)
        {
          NodeUtils::Async::RunCallbackOnMain(asyncToken, [exception](NodeUtils::InvokeCallbackDelegate invokeCallback) {
             
            Handle<Value> error = NodeRT::Utils::WinRtExceptionToJsError(exception);
        
            Handle<Value> args[] = {error};
            invokeCallback(_countof(args), args);
          });
        }  		
      });

      return scope.Close(Undefined());
    }
    static Handle<Value> GetMessageAsync(const v8::Arguments& args)
    {
      HandleScope scope;

      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Devices::Sms::SmsDeviceMessageStore^>(args.This()))
      {
        return scope.Close(Undefined());
      }

      if (args.Length() == 0 || !args[args.Length() -1]->IsFunction())
      {
          ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Bad arguments: No callback was given")));
          return scope.Close(Undefined());
      }

      SmsDeviceMessageStore *wrapper = SmsDeviceMessageStore::Unwrap<SmsDeviceMessageStore>(args.This());

      ::Windows::Foundation::IAsyncOperation<::Windows::Devices::Sms::ISmsMessage^>^ op;
    

      if (args.Length() == 2
        && args[0]->IsUint32())
      {
        try
        {
          unsigned int arg0 = static_cast<unsigned int>(args[0]->IntegerValue());
          
          op = wrapper->_instance->GetMessageAsync(arg0);
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else 
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Bad arguments: no suitable overload found")));
        return scope.Close(Undefined());
      }
    
      auto opTask = create_task(op);
      uv_async_t* asyncToken = NodeUtils::Async::GetAsyncToken(args[args.Length() -1].As<Function>());

      opTask.then( [asyncToken] (task<::Windows::Devices::Sms::ISmsMessage^> t) 
      {	
        try
        {
          auto result = t.get();
          NodeUtils::Async::RunCallbackOnMain(asyncToken, [result](NodeUtils::InvokeCallbackDelegate invokeCallback) {


            TryCatch tryCatch;
            Handle<Value> error; 
            Handle<Value> arg1 = WrapISmsMessage(result);
            if (tryCatch.HasCaught())
            {
              error = tryCatch.Exception()->ToObject();
            }
            else 
            {
              error = Undefined();
            }
            if (arg1.IsEmpty()) arg1 = Undefined();
            Handle<Value> args[] = {error, arg1};

            invokeCallback(_countof(args), args);
          });
        }
        catch (Platform::Exception^ exception)
        {
          NodeUtils::Async::RunCallbackOnMain(asyncToken, [exception](NodeUtils::InvokeCallbackDelegate invokeCallback) {
             
            Handle<Value> error = NodeRT::Utils::WinRtExceptionToJsError(exception);
        
            Handle<Value> args[] = {error};
            invokeCallback(_countof(args), args);
          });
        }  		
      });

      return scope.Close(Undefined());
    }
    static Handle<Value> GetMessagesAsync(const v8::Arguments& args)
    {
      HandleScope scope;

      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Devices::Sms::SmsDeviceMessageStore^>(args.This()))
      {
        return scope.Close(Undefined());
      }

      if (args.Length() == 0 || !args[args.Length() -1]->IsFunction())
      {
          ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Bad arguments: No callback was given")));
          return scope.Close(Undefined());
      }

      SmsDeviceMessageStore *wrapper = SmsDeviceMessageStore::Unwrap<SmsDeviceMessageStore>(args.This());

      ::Windows::Foundation::IAsyncOperationWithProgress<::Windows::Foundation::Collections::IVectorView<::Windows::Devices::Sms::ISmsMessage^>^, int>^ op;
    

      if (args.Length() == 2
        && args[0]->IsInt32())
      {
        try
        {
          ::Windows::Devices::Sms::SmsMessageFilter arg0 = static_cast<::Windows::Devices::Sms::SmsMessageFilter>(args[0]->Int32Value());
          
          op = wrapper->_instance->GetMessagesAsync(arg0);
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else 
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Bad arguments: no suitable overload found")));
        return scope.Close(Undefined());
      }
    
      auto opTask = create_task(op);
      uv_async_t* asyncToken = NodeUtils::Async::GetAsyncToken(args[args.Length() -1].As<Function>());

      opTask.then( [asyncToken] (task<::Windows::Foundation::Collections::IVectorView<::Windows::Devices::Sms::ISmsMessage^>^> t) 
      {	
        try
        {
          auto result = t.get();
          NodeUtils::Async::RunCallbackOnMain(asyncToken, [result](NodeUtils::InvokeCallbackDelegate invokeCallback) {


            TryCatch tryCatch;
            Handle<Value> error; 
            Handle<Value> arg1 = NodeRT::Collections::VectorViewWrapper<::Windows::Devices::Sms::ISmsMessage^>::CreateVectorViewWrapper(result, 
            [](::Windows::Devices::Sms::ISmsMessage^ val) -> Handle<Value> {
              return WrapISmsMessage(val);
            },
            [](Handle<Value> value) -> bool {
              return NodeRT::Utils::IsWinRtWrapperOf<::Windows::Devices::Sms::ISmsMessage^>(value);
            },
            [](Handle<Value> value) -> ::Windows::Devices::Sms::ISmsMessage^ {
              return UnwrapISmsMessage(value);
            }
          );
            if (tryCatch.HasCaught())
            {
              error = tryCatch.Exception()->ToObject();
            }
            else 
            {
              error = Undefined();
            }
            if (arg1.IsEmpty()) arg1 = Undefined();
            Handle<Value> args[] = {error, arg1};

            invokeCallback(_countof(args), args);
          });
        }
        catch (Platform::Exception^ exception)
        {
          NodeUtils::Async::RunCallbackOnMain(asyncToken, [exception](NodeUtils::InvokeCallbackDelegate invokeCallback) {
             
            Handle<Value> error = NodeRT::Utils::WinRtExceptionToJsError(exception);
        
            Handle<Value> args[] = {error};
            invokeCallback(_countof(args), args);
          });
        }  		
      });

      return scope.Close(Undefined());
    }
  



    static Handle<Value> MaxMessagesGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Devices::Sms::SmsDeviceMessageStore^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      SmsDeviceMessageStore *wrapper = SmsDeviceMessageStore::Unwrap<SmsDeviceMessageStore>(info.This());

      try 
      {
        unsigned int result = wrapper->_instance->MaxMessages;
        return scope.Close(Integer::New(result));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    


  private:
    ::Windows::Devices::Sms::SmsDeviceMessageStore^ _instance;
    static Persistent<FunctionTemplate> s_constructorTemplate;

    friend v8::Handle<v8::Value> WrapSmsDeviceMessageStore(::Windows::Devices::Sms::SmsDeviceMessageStore^ wintRtInstance);
    friend ::Windows::Devices::Sms::SmsDeviceMessageStore^ UnwrapSmsDeviceMessageStore(Handle<Value> value);
    friend bool IsSmsDeviceMessageStoreWrapper(Handle<Value> value);
  };
  Persistent<FunctionTemplate> SmsDeviceMessageStore::s_constructorTemplate;

  v8::Handle<v8::Value> WrapSmsDeviceMessageStore(::Windows::Devices::Sms::SmsDeviceMessageStore^ winRtInstance)
  {
    HandleScope scope;

    if (winRtInstance == nullptr)
    {
      return scope.Close(Undefined());
    }

    Handle<Object> opaqueWrapper = CreateOpaqueWrapper(winRtInstance);
    Handle<Value> args[] = {opaqueWrapper};
    return scope.Close(SmsDeviceMessageStore::s_constructorTemplate->GetFunction()->NewInstance(_countof(args), args));
  }

  ::Windows::Devices::Sms::SmsDeviceMessageStore^ UnwrapSmsDeviceMessageStore(Handle<Value> value)
  {
     return SmsDeviceMessageStore::Unwrap<SmsDeviceMessageStore>(value.As<Object>())->_instance;
  }

  void InitSmsDeviceMessageStore(Handle<Object> exports)
  {
    SmsDeviceMessageStore::Init(exports);
  }

  class SendSmsMessageOperation : public WrapperBase
  {
  public:    
    static v8::Handle<v8::Value> Init(const Handle<Object> exports)
    {
      HandleScope scope;
      
      s_constructorTemplate = Persistent<FunctionTemplate>::New(FunctionTemplate::New(New));
      s_constructorTemplate->SetClassName(String::NewSymbol("SendSmsMessageOperation"));
      s_constructorTemplate->InstanceTemplate()->SetInternalFieldCount(1);
      
            
      s_constructorTemplate->PrototypeTemplate()->Set(String::NewSymbol("getResults"), FunctionTemplate::New(GetResults)->GetFunction());
      s_constructorTemplate->PrototypeTemplate()->Set(String::NewSymbol("cancel"), FunctionTemplate::New(Cancel)->GetFunction());
      s_constructorTemplate->PrototypeTemplate()->Set(String::NewSymbol("close"), FunctionTemplate::New(Close)->GetFunction());
      
                        
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("completed"), CompletedGetter, CompletedSetter);
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("errorCode"), ErrorCodeGetter);
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("id"), IdGetter);
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("status"), StatusGetter);
      
      Local<Function> constructor = s_constructorTemplate->GetFunction();


      exports->Set(String::NewSymbol("SendSmsMessageOperation"), constructor);
      return scope.Close(Undefined());
    }


    virtual ::Platform::Object^ GetObjectInstance() const override
    {
      return _instance;
    }

  private:
    
    SendSmsMessageOperation(::Windows::Devices::Sms::SendSmsMessageOperation^ instance)
    {
      _instance = instance;
    }
    
    
    static v8::Handle<v8::Value> New(const v8::Arguments& args)
    {
      HandleScope scope;

      // in case the constructor was called without the new operator
      if (!s_constructorTemplate->HasInstance(args.This()))
      {
        if (args.Length() > 0)
        {
          std::unique_ptr<Handle<Value> []> constructorArgs(new Handle<Value>[args.Length()]);

          Handle<Value> *argsPtr = constructorArgs.get();
          for (int i = 0; i < args.Length(); i++)
          {
            argsPtr[i] = args[i];
          }

          return s_constructorTemplate->GetFunction()->CallAsConstructor(args.Length(), constructorArgs.get());
        }
        else
        {
          return s_constructorTemplate->GetFunction()->CallAsConstructor(args.Length(), nullptr);
        }
      }
      
      ::Windows::Devices::Sms::SendSmsMessageOperation^ winRtInstance;


      if (args.Length() == 1 && OpaqueWrapper::IsOpaqueWrapper(args[0]) &&
        NodeRT::Utils::IsWinRtWrapperOf<::Windows::Devices::Sms::SendSmsMessageOperation^>(args[0]))
      {
        try 
        {
          winRtInstance = (::Windows::Devices::Sms::SendSmsMessageOperation^) NodeRT::Utils::GetObjectInstance(args[0]);
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Invalid arguments, no suitable constructor found")));
        return scope.Close(Undefined());
      }

      args.This()->SetHiddenValue(String::NewSymbol("__winRtInstance__"), True());

      SendSmsMessageOperation *wrapperInstance = new SendSmsMessageOperation(winRtInstance);
      wrapperInstance->Wrap(args.This());

      return args.This();
    }


  
    static Handle<Value> GetResults(const v8::Arguments& args)
    {
      HandleScope scope;

      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Devices::Sms::SendSmsMessageOperation^>(args.This()))
      {
        return scope.Close(Undefined());
      }

      SendSmsMessageOperation *wrapper = SendSmsMessageOperation::Unwrap<SendSmsMessageOperation>(args.This());

      if (args.Length() == 0)
      {
        try
        {
          wrapper->_instance->GetResults();
          return scope.Close(Undefined());   
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else 
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Bad arguments: no suitable overload found")));
        return scope.Close(Undefined());
      }

      return scope.Close(Undefined());
    }
    static Handle<Value> Cancel(const v8::Arguments& args)
    {
      HandleScope scope;

      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Devices::Sms::SendSmsMessageOperation^>(args.This()))
      {
        return scope.Close(Undefined());
      }

      SendSmsMessageOperation *wrapper = SendSmsMessageOperation::Unwrap<SendSmsMessageOperation>(args.This());

      if (args.Length() == 0)
      {
        try
        {
          wrapper->_instance->Cancel();
          return scope.Close(Undefined());   
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else 
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Bad arguments: no suitable overload found")));
        return scope.Close(Undefined());
      }

      return scope.Close(Undefined());
    }
    static Handle<Value> Close(const v8::Arguments& args)
    {
      HandleScope scope;

      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Devices::Sms::SendSmsMessageOperation^>(args.This()))
      {
        return scope.Close(Undefined());
      }

      SendSmsMessageOperation *wrapper = SendSmsMessageOperation::Unwrap<SendSmsMessageOperation>(args.This());

      if (args.Length() == 0)
      {
        try
        {
          wrapper->_instance->Close();
          return scope.Close(Undefined());   
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else 
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Bad arguments: no suitable overload found")));
        return scope.Close(Undefined());
      }

      return scope.Close(Undefined());
    }



    static Handle<Value> CompletedGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Devices::Sms::SendSmsMessageOperation^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      SendSmsMessageOperation *wrapper = SendSmsMessageOperation::Unwrap<SendSmsMessageOperation>(info.This());

      try 
      {
        ::Windows::Foundation::AsyncActionCompletedHandler^ result = wrapper->_instance->Completed;
        return scope.Close(NodeRT::Utils::CreateExternalWinRTObject("Windows.Foundation", "AsyncActionCompletedHandler", result));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    
    static void CompletedSetter(Local<String> property, Local<Value> value, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Foundation::AsyncActionCompletedHandler^>(value))
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Value to set is of unexpected type")));
        return;
      }

      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Devices::Sms::SendSmsMessageOperation^>(info.This()))
      {
        return;
      }

      SendSmsMessageOperation *wrapper = SendSmsMessageOperation::Unwrap<SendSmsMessageOperation>(info.This());

      try 
      {
        
        ::Windows::Foundation::AsyncActionCompletedHandler^ winRtValue = dynamic_cast<::Windows::Foundation::AsyncActionCompletedHandler^>(NodeRT::Utils::GetObjectInstance(value));

        wrapper->_instance->Completed = winRtValue;
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
      }
    }
    
    static Handle<Value> ErrorCodeGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Devices::Sms::SendSmsMessageOperation^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      SendSmsMessageOperation *wrapper = SendSmsMessageOperation::Unwrap<SendSmsMessageOperation>(info.This());

      try 
      {
        ::Windows::Foundation::HResult result = wrapper->_instance->ErrorCode;
        return scope.Close(Integer::New(result.Value));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    
    static Handle<Value> IdGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Devices::Sms::SendSmsMessageOperation^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      SendSmsMessageOperation *wrapper = SendSmsMessageOperation::Unwrap<SendSmsMessageOperation>(info.This());

      try 
      {
        unsigned int result = wrapper->_instance->Id;
        return scope.Close(Integer::New(result));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    
    static Handle<Value> StatusGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Devices::Sms::SendSmsMessageOperation^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      SendSmsMessageOperation *wrapper = SendSmsMessageOperation::Unwrap<SendSmsMessageOperation>(info.This());

      try 
      {
        ::Windows::Foundation::AsyncStatus result = wrapper->_instance->Status;
        return scope.Close(Integer::New(static_cast<int>(result)));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    


  private:
    ::Windows::Devices::Sms::SendSmsMessageOperation^ _instance;
    static Persistent<FunctionTemplate> s_constructorTemplate;

    friend v8::Handle<v8::Value> WrapSendSmsMessageOperation(::Windows::Devices::Sms::SendSmsMessageOperation^ wintRtInstance);
    friend ::Windows::Devices::Sms::SendSmsMessageOperation^ UnwrapSendSmsMessageOperation(Handle<Value> value);
    friend bool IsSendSmsMessageOperationWrapper(Handle<Value> value);
  };
  Persistent<FunctionTemplate> SendSmsMessageOperation::s_constructorTemplate;

  v8::Handle<v8::Value> WrapSendSmsMessageOperation(::Windows::Devices::Sms::SendSmsMessageOperation^ winRtInstance)
  {
    HandleScope scope;

    if (winRtInstance == nullptr)
    {
      return scope.Close(Undefined());
    }

    Handle<Object> opaqueWrapper = CreateOpaqueWrapper(winRtInstance);
    Handle<Value> args[] = {opaqueWrapper};
    return scope.Close(SendSmsMessageOperation::s_constructorTemplate->GetFunction()->NewInstance(_countof(args), args));
  }

  ::Windows::Devices::Sms::SendSmsMessageOperation^ UnwrapSendSmsMessageOperation(Handle<Value> value)
  {
     return SendSmsMessageOperation::Unwrap<SendSmsMessageOperation>(value.As<Object>())->_instance;
  }

  void InitSendSmsMessageOperation(Handle<Object> exports)
  {
    SendSmsMessageOperation::Init(exports);
  }

  class SmsMessageReceivedEventArgs : public WrapperBase
  {
  public:    
    static v8::Handle<v8::Value> Init(const Handle<Object> exports)
    {
      HandleScope scope;
      
      s_constructorTemplate = Persistent<FunctionTemplate>::New(FunctionTemplate::New(New));
      s_constructorTemplate->SetClassName(String::NewSymbol("SmsMessageReceivedEventArgs"));
      s_constructorTemplate->InstanceTemplate()->SetInternalFieldCount(1);
      
                              
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("binaryMessage"), BinaryMessageGetter);
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("textMessage"), TextMessageGetter);
      
      Local<Function> constructor = s_constructorTemplate->GetFunction();


      exports->Set(String::NewSymbol("SmsMessageReceivedEventArgs"), constructor);
      return scope.Close(Undefined());
    }


    virtual ::Platform::Object^ GetObjectInstance() const override
    {
      return _instance;
    }

  private:
    
    SmsMessageReceivedEventArgs(::Windows::Devices::Sms::SmsMessageReceivedEventArgs^ instance)
    {
      _instance = instance;
    }
    
    
    static v8::Handle<v8::Value> New(const v8::Arguments& args)
    {
      HandleScope scope;

      // in case the constructor was called without the new operator
      if (!s_constructorTemplate->HasInstance(args.This()))
      {
        if (args.Length() > 0)
        {
          std::unique_ptr<Handle<Value> []> constructorArgs(new Handle<Value>[args.Length()]);

          Handle<Value> *argsPtr = constructorArgs.get();
          for (int i = 0; i < args.Length(); i++)
          {
            argsPtr[i] = args[i];
          }

          return s_constructorTemplate->GetFunction()->CallAsConstructor(args.Length(), constructorArgs.get());
        }
        else
        {
          return s_constructorTemplate->GetFunction()->CallAsConstructor(args.Length(), nullptr);
        }
      }
      
      ::Windows::Devices::Sms::SmsMessageReceivedEventArgs^ winRtInstance;


      if (args.Length() == 1 && OpaqueWrapper::IsOpaqueWrapper(args[0]) &&
        NodeRT::Utils::IsWinRtWrapperOf<::Windows::Devices::Sms::SmsMessageReceivedEventArgs^>(args[0]))
      {
        try 
        {
          winRtInstance = (::Windows::Devices::Sms::SmsMessageReceivedEventArgs^) NodeRT::Utils::GetObjectInstance(args[0]);
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Invalid arguments, no suitable constructor found")));
        return scope.Close(Undefined());
      }

      args.This()->SetHiddenValue(String::NewSymbol("__winRtInstance__"), True());

      SmsMessageReceivedEventArgs *wrapperInstance = new SmsMessageReceivedEventArgs(winRtInstance);
      wrapperInstance->Wrap(args.This());

      return args.This();
    }


  



    static Handle<Value> BinaryMessageGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Devices::Sms::SmsMessageReceivedEventArgs^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      SmsMessageReceivedEventArgs *wrapper = SmsMessageReceivedEventArgs::Unwrap<SmsMessageReceivedEventArgs>(info.This());

      try 
      {
        ::Windows::Devices::Sms::SmsBinaryMessage^ result = wrapper->_instance->BinaryMessage;
        return scope.Close(WrapSmsBinaryMessage(result));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    
    static Handle<Value> TextMessageGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Devices::Sms::SmsMessageReceivedEventArgs^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      SmsMessageReceivedEventArgs *wrapper = SmsMessageReceivedEventArgs::Unwrap<SmsMessageReceivedEventArgs>(info.This());

      try 
      {
        ::Windows::Devices::Sms::SmsTextMessage^ result = wrapper->_instance->TextMessage;
        return scope.Close(WrapSmsTextMessage(result));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    


  private:
    ::Windows::Devices::Sms::SmsMessageReceivedEventArgs^ _instance;
    static Persistent<FunctionTemplate> s_constructorTemplate;

    friend v8::Handle<v8::Value> WrapSmsMessageReceivedEventArgs(::Windows::Devices::Sms::SmsMessageReceivedEventArgs^ wintRtInstance);
    friend ::Windows::Devices::Sms::SmsMessageReceivedEventArgs^ UnwrapSmsMessageReceivedEventArgs(Handle<Value> value);
    friend bool IsSmsMessageReceivedEventArgsWrapper(Handle<Value> value);
  };
  Persistent<FunctionTemplate> SmsMessageReceivedEventArgs::s_constructorTemplate;

  v8::Handle<v8::Value> WrapSmsMessageReceivedEventArgs(::Windows::Devices::Sms::SmsMessageReceivedEventArgs^ winRtInstance)
  {
    HandleScope scope;

    if (winRtInstance == nullptr)
    {
      return scope.Close(Undefined());
    }

    Handle<Object> opaqueWrapper = CreateOpaqueWrapper(winRtInstance);
    Handle<Value> args[] = {opaqueWrapper};
    return scope.Close(SmsMessageReceivedEventArgs::s_constructorTemplate->GetFunction()->NewInstance(_countof(args), args));
  }

  ::Windows::Devices::Sms::SmsMessageReceivedEventArgs^ UnwrapSmsMessageReceivedEventArgs(Handle<Value> value)
  {
     return SmsMessageReceivedEventArgs::Unwrap<SmsMessageReceivedEventArgs>(value.As<Object>())->_instance;
  }

  void InitSmsMessageReceivedEventArgs(Handle<Object> exports)
  {
    SmsMessageReceivedEventArgs::Init(exports);
  }

  class SmsDevice : public WrapperBase
  {
  public:    
    static v8::Handle<v8::Value> Init(const Handle<Object> exports)
    {
      HandleScope scope;
      
      s_constructorTemplate = Persistent<FunctionTemplate>::New(FunctionTemplate::New(New));
      s_constructorTemplate->SetClassName(String::NewSymbol("SmsDevice"));
      s_constructorTemplate->InstanceTemplate()->SetInternalFieldCount(1);
      
      Handle<Value> asyncSymbol = String::NewSymbol("__winRtAsync__");
      Handle<Function> func;
            
      s_constructorTemplate->PrototypeTemplate()->Set(String::NewSymbol("calculateLength"), FunctionTemplate::New(CalculateLength)->GetFunction());
      
            
      func = FunctionTemplate::New(SendMessageAsync)->GetFunction();
      func->Set(asyncSymbol, True(), PropertyAttribute::DontEnum);
      s_constructorTemplate->PrototypeTemplate()->Set(String::NewSymbol("sendMessageAsync"), func);
      
            
      Local<Function> addListenerFunc = FunctionTemplate::New(AddListener)->GetFunction();
      s_constructorTemplate->PrototypeTemplate()->Set(String::NewSymbol("addListener"), addListenerFunc);
      s_constructorTemplate->PrototypeTemplate()->Set(String::NewSymbol("on"), addListenerFunc);
      Local<Function> removeListenerFunc = FunctionTemplate::New(RemoveListener)->GetFunction();
      s_constructorTemplate->PrototypeTemplate()->Set(String::NewSymbol("removeListener"), removeListenerFunc);
      s_constructorTemplate->PrototypeTemplate()->Set(String::NewSymbol("off"), removeListenerFunc);
            
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("accountPhoneNumber"), AccountPhoneNumberGetter);
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("cellularClass"), CellularClassGetter);
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("deviceStatus"), DeviceStatusGetter);
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("messageStore"), MessageStoreGetter);
      
      Local<Function> constructor = s_constructorTemplate->GetFunction();

      constructor->Set(String::NewSymbol("getDeviceSelector"), FunctionTemplate::New(GetDeviceSelector)->GetFunction());
      func = FunctionTemplate::New(FromNetworkAccountIdAsync)->GetFunction();
      func->Set(asyncSymbol, True(), PropertyAttribute::DontEnum);
      constructor->Set(String::NewSymbol("fromNetworkAccountIdAsync"), func);
      func = FunctionTemplate::New(FromIdAsync)->GetFunction();
      func->Set(asyncSymbol, True(), PropertyAttribute::DontEnum);
      constructor->Set(String::NewSymbol("fromIdAsync"), func);
      func = FunctionTemplate::New(GetDefaultAsync)->GetFunction();
      func->Set(asyncSymbol, True(), PropertyAttribute::DontEnum);
      constructor->Set(String::NewSymbol("getDefaultAsync"), func);

      exports->Set(String::NewSymbol("SmsDevice"), constructor);
      return scope.Close(Undefined());
    }


    virtual ::Platform::Object^ GetObjectInstance() const override
    {
      return _instance;
    }

  private:
    
    SmsDevice(::Windows::Devices::Sms::SmsDevice^ instance)
    {
      _instance = instance;
    }
    
    
    static v8::Handle<v8::Value> New(const v8::Arguments& args)
    {
      HandleScope scope;

      // in case the constructor was called without the new operator
      if (!s_constructorTemplate->HasInstance(args.This()))
      {
        if (args.Length() > 0)
        {
          std::unique_ptr<Handle<Value> []> constructorArgs(new Handle<Value>[args.Length()]);

          Handle<Value> *argsPtr = constructorArgs.get();
          for (int i = 0; i < args.Length(); i++)
          {
            argsPtr[i] = args[i];
          }

          return s_constructorTemplate->GetFunction()->CallAsConstructor(args.Length(), constructorArgs.get());
        }
        else
        {
          return s_constructorTemplate->GetFunction()->CallAsConstructor(args.Length(), nullptr);
        }
      }
      
      ::Windows::Devices::Sms::SmsDevice^ winRtInstance;


      if (args.Length() == 1 && OpaqueWrapper::IsOpaqueWrapper(args[0]) &&
        NodeRT::Utils::IsWinRtWrapperOf<::Windows::Devices::Sms::SmsDevice^>(args[0]))
      {
        try 
        {
          winRtInstance = (::Windows::Devices::Sms::SmsDevice^) NodeRT::Utils::GetObjectInstance(args[0]);
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Invalid arguments, no suitable constructor found")));
        return scope.Close(Undefined());
      }

      args.This()->SetHiddenValue(String::NewSymbol("__winRtInstance__"), True());

      SmsDevice *wrapperInstance = new SmsDevice(winRtInstance);
      wrapperInstance->Wrap(args.This());

      return args.This();
    }


    static Handle<Value> SendMessageAsync(const v8::Arguments& args)
    {
      HandleScope scope;

      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Devices::Sms::SmsDevice^>(args.This()))
      {
        return scope.Close(Undefined());
      }

      if (args.Length() == 0 || !args[args.Length() -1]->IsFunction())
      {
          ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Bad arguments: No callback was given")));
          return scope.Close(Undefined());
      }

      SmsDevice *wrapper = SmsDevice::Unwrap<SmsDevice>(args.This());

      ::Windows::Devices::Sms::SendSmsMessageOperation^ op;
    

      if (args.Length() == 2
        && NodeRT::Utils::IsWinRtWrapperOf<::Windows::Devices::Sms::ISmsMessage^>(args[0]))
      {
        try
        {
          ::Windows::Devices::Sms::ISmsMessage^ arg0 = UnwrapISmsMessage(args[0]);
          
          op = wrapper->_instance->SendMessageAsync(arg0);
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else 
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Bad arguments: no suitable overload found")));
        return scope.Close(Undefined());
      }
    
      auto opTask = create_task(op);
      uv_async_t* asyncToken = NodeUtils::Async::GetAsyncToken(args[args.Length() -1].As<Function>());

      opTask.then( [asyncToken] (task<void> t) 
      {	
        try
        {
          t.get();
          NodeUtils::Async::RunCallbackOnMain(asyncToken, [](NodeUtils::InvokeCallbackDelegate invokeCallback) {


            Handle<Value> args[] = {Undefined()};

            invokeCallback(_countof(args), args);
          });
        }
        catch (Platform::Exception^ exception)
        {
          NodeUtils::Async::RunCallbackOnMain(asyncToken, [exception](NodeUtils::InvokeCallbackDelegate invokeCallback) {
             
            Handle<Value> error = NodeRT::Utils::WinRtExceptionToJsError(exception);
        
            Handle<Value> args[] = {error};
            invokeCallback(_countof(args), args);
          });
        }  		
      });

      return scope.Close(Undefined());
    }
  
    static Handle<Value> CalculateLength(const v8::Arguments& args)
    {
      HandleScope scope;

      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Devices::Sms::SmsDevice^>(args.This()))
      {
        return scope.Close(Undefined());
      }

      SmsDevice *wrapper = SmsDevice::Unwrap<SmsDevice>(args.This());

      if (args.Length() == 1
        && NodeRT::Utils::IsWinRtWrapperOf<::Windows::Devices::Sms::SmsTextMessage^>(args[0]))
      {
        try
        {
          ::Windows::Devices::Sms::SmsTextMessage^ arg0 = UnwrapSmsTextMessage(args[0]);
          
          ::Windows::Devices::Sms::SmsEncodedLength result;
          result = wrapper->_instance->CalculateLength(arg0);
          return scope.Close(SmsEncodedLengthToJsObject(result));
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else 
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Bad arguments: no suitable overload found")));
        return scope.Close(Undefined());
      }

      return scope.Close(Undefined());
    }

    static Handle<Value> FromNetworkAccountIdAsync(const v8::Arguments& args)
    {
      HandleScope scope;

      if (args.Length() == 0 || !args[args.Length() -1]->IsFunction())
      {
          ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Bad arguments: No callback was given")));
          return scope.Close(Undefined());
      }

      ::Windows::Foundation::IAsyncOperation<::Windows::Devices::Sms::SmsDevice^>^ op;
      

      if (args.Length() == 2
        && args[0]->IsString())
      {
        try
        {
          Platform::String^ arg0 = ref new Platform::String(NodeRT::Utils::StringToWchar(v8::String::Value(args[0])));
          
          op = ::Windows::Devices::Sms::SmsDevice::FromNetworkAccountIdAsync(arg0);
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else 
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Bad arguments: no suitable overload found")));
        return scope.Close(Undefined());
      }
    
      auto opTask = create_task(op);
      uv_async_t* asyncToken = NodeUtils::Async::GetAsyncToken(args[args.Length() -1].As<Function>());

      opTask.then( [asyncToken] (task<::Windows::Devices::Sms::SmsDevice^> t) 
      {	
        try
        {
          auto result = t.get();
          NodeUtils::Async::RunCallbackOnMain(asyncToken, [result](NodeUtils::InvokeCallbackDelegate invokeCallback) {

            
            TryCatch tryCatch;
            Handle<Value> error; 
            Handle<Value> arg1 = WrapSmsDevice(result);
            if (tryCatch.HasCaught())
            {
              error = tryCatch.Exception()->ToObject();
            }
            else 
            {
              error = Undefined();
            }
            if (arg1.IsEmpty()) arg1 = Undefined();
            Handle<Value> args[] = {error, arg1};

            invokeCallback(_countof(args), args);
          });
        }
        catch (Platform::Exception^ exception)
        {
          NodeUtils::Async::RunCallbackOnMain(asyncToken, [exception](NodeUtils::InvokeCallbackDelegate invokeCallback) {
          
            Handle<Value> error = NodeRT::Utils::WinRtExceptionToJsError(exception);
        
            Handle<Value> args[] = {error};
            invokeCallback(_countof(args), args);
          });
        }  		
      });

      return scope.Close(Undefined());
    }
    static Handle<Value> FromIdAsync(const v8::Arguments& args)
    {
      HandleScope scope;

      if (args.Length() == 0 || !args[args.Length() -1]->IsFunction())
      {
          ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Bad arguments: No callback was given")));
          return scope.Close(Undefined());
      }

      ::Windows::Foundation::IAsyncOperation<::Windows::Devices::Sms::SmsDevice^>^ op;
      

      if (args.Length() == 2
        && args[0]->IsString())
      {
        try
        {
          Platform::String^ arg0 = ref new Platform::String(NodeRT::Utils::StringToWchar(v8::String::Value(args[0])));
          
          op = ::Windows::Devices::Sms::SmsDevice::FromIdAsync(arg0);
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else 
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Bad arguments: no suitable overload found")));
        return scope.Close(Undefined());
      }
    
      auto opTask = create_task(op);
      uv_async_t* asyncToken = NodeUtils::Async::GetAsyncToken(args[args.Length() -1].As<Function>());

      opTask.then( [asyncToken] (task<::Windows::Devices::Sms::SmsDevice^> t) 
      {	
        try
        {
          auto result = t.get();
          NodeUtils::Async::RunCallbackOnMain(asyncToken, [result](NodeUtils::InvokeCallbackDelegate invokeCallback) {

            
            TryCatch tryCatch;
            Handle<Value> error; 
            Handle<Value> arg1 = WrapSmsDevice(result);
            if (tryCatch.HasCaught())
            {
              error = tryCatch.Exception()->ToObject();
            }
            else 
            {
              error = Undefined();
            }
            if (arg1.IsEmpty()) arg1 = Undefined();
            Handle<Value> args[] = {error, arg1};

            invokeCallback(_countof(args), args);
          });
        }
        catch (Platform::Exception^ exception)
        {
          NodeUtils::Async::RunCallbackOnMain(asyncToken, [exception](NodeUtils::InvokeCallbackDelegate invokeCallback) {
          
            Handle<Value> error = NodeRT::Utils::WinRtExceptionToJsError(exception);
        
            Handle<Value> args[] = {error};
            invokeCallback(_countof(args), args);
          });
        }  		
      });

      return scope.Close(Undefined());
    }
    static Handle<Value> GetDefaultAsync(const v8::Arguments& args)
    {
      HandleScope scope;

      if (args.Length() == 0 || !args[args.Length() -1]->IsFunction())
      {
          ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Bad arguments: No callback was given")));
          return scope.Close(Undefined());
      }

      ::Windows::Foundation::IAsyncOperation<::Windows::Devices::Sms::SmsDevice^>^ op;
      

      if (args.Length() == 1)
      {
        try
        {
          op = ::Windows::Devices::Sms::SmsDevice::GetDefaultAsync();
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else 
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Bad arguments: no suitable overload found")));
        return scope.Close(Undefined());
      }
    
      auto opTask = create_task(op);
      uv_async_t* asyncToken = NodeUtils::Async::GetAsyncToken(args[args.Length() -1].As<Function>());

      opTask.then( [asyncToken] (task<::Windows::Devices::Sms::SmsDevice^> t) 
      {	
        try
        {
          auto result = t.get();
          NodeUtils::Async::RunCallbackOnMain(asyncToken, [result](NodeUtils::InvokeCallbackDelegate invokeCallback) {

            
            TryCatch tryCatch;
            Handle<Value> error; 
            Handle<Value> arg1 = WrapSmsDevice(result);
            if (tryCatch.HasCaught())
            {
              error = tryCatch.Exception()->ToObject();
            }
            else 
            {
              error = Undefined();
            }
            if (arg1.IsEmpty()) arg1 = Undefined();
            Handle<Value> args[] = {error, arg1};

            invokeCallback(_countof(args), args);
          });
        }
        catch (Platform::Exception^ exception)
        {
          NodeUtils::Async::RunCallbackOnMain(asyncToken, [exception](NodeUtils::InvokeCallbackDelegate invokeCallback) {
          
            Handle<Value> error = NodeRT::Utils::WinRtExceptionToJsError(exception);
        
            Handle<Value> args[] = {error};
            invokeCallback(_countof(args), args);
          });
        }  		
      });

      return scope.Close(Undefined());
    }

    static Handle<Value> GetDeviceSelector(const v8::Arguments& args)
    {
      HandleScope scope;

      if (args.Length() == 0)
      {
        try
        {
          Platform::String^ result;
          result = ::Windows::Devices::Sms::SmsDevice::GetDeviceSelector();
          return scope.Close(NodeRT::Utils::NewString(result->Data()));
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else 
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Bad arguments: no suitable overload found")));
        return scope.Close(Undefined());
      }

      return scope.Close(Undefined());
    }

    static Handle<Value> AccountPhoneNumberGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Devices::Sms::SmsDevice^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      SmsDevice *wrapper = SmsDevice::Unwrap<SmsDevice>(info.This());

      try 
      {
        Platform::String^ result = wrapper->_instance->AccountPhoneNumber;
        return scope.Close(NodeRT::Utils::NewString(result->Data()));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    
    static Handle<Value> CellularClassGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Devices::Sms::SmsDevice^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      SmsDevice *wrapper = SmsDevice::Unwrap<SmsDevice>(info.This());

      try 
      {
        ::Windows::Devices::Sms::CellularClass result = wrapper->_instance->CellularClass;
        return scope.Close(Integer::New(static_cast<int>(result)));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    
    static Handle<Value> DeviceStatusGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Devices::Sms::SmsDevice^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      SmsDevice *wrapper = SmsDevice::Unwrap<SmsDevice>(info.This());

      try 
      {
        ::Windows::Devices::Sms::SmsDeviceStatus result = wrapper->_instance->DeviceStatus;
        return scope.Close(Integer::New(static_cast<int>(result)));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    
    static Handle<Value> MessageStoreGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Devices::Sms::SmsDevice^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      SmsDevice *wrapper = SmsDevice::Unwrap<SmsDevice>(info.This());

      try 
      {
        ::Windows::Devices::Sms::SmsDeviceMessageStore^ result = wrapper->_instance->MessageStore;
        return scope.Close(WrapSmsDeviceMessageStore(result));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    


    static v8::Handle<v8::Value> AddListener(const v8::Arguments& args)
    {
      HandleScope scope;

      if (args.Length() < 2 || !args[0]->IsString() || !args[1]->IsFunction())
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"wrong arguments, expected arguments are eventName(string),callback(function)")));
        return scope.Close(Undefined());
      }

      String::Value eventName(args[0]);
      auto str = *eventName;
      
      Local<Function> callback = args[1].As<Function>();
      
      ::Windows::Foundation::EventRegistrationToken registrationToken;
      if (NodeRT::Utils::CaseInsenstiveEquals(L"smsDeviceStatusChanged", str))
      {
        if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Devices::Sms::SmsDevice^>(args.This()))
        {
          ThrowException(Exception::Error(NodeRT::Utils::NewString(L"The caller of this method isn't of the expected type or internal WinRt object was disposed")));
          return scope.Close(Undefined());
        }
        SmsDevice *wrapper = SmsDevice::Unwrap<SmsDevice>(args.This());
      
        try
        {
          std::shared_ptr<Persistent<Object>> callbackObjPtr(new Persistent<Object>(Persistent<Object>::New(NodeRT::Utils::CreateCallbackObjectInDomain(callback))), 
            [] (Persistent<Object> *ptr ) {
              NodeUtils::Async::RunOnMain([ptr]() {
                ptr->Dispose();
                delete ptr;
            });
          });

          registrationToken = wrapper->_instance->SmsDeviceStatusChanged::add(
            ref new ::Windows::Devices::Sms::SmsDeviceStatusChangedEventHandler(
            [callbackObjPtr](::Windows::Devices::Sms::SmsDevice^ arg0) {
              NodeUtils::Async::RunOnMain([callbackObjPtr , arg0]() {
                TryCatch tryCatch;
              
                Handle<Value> error;

                Handle<Value> wrappedArg0 = WrapSmsDevice(arg0);

                if (tryCatch.HasCaught())
                {
                  error = tryCatch.Exception()->ToObject();
                }
                else 
                {
                  error = Undefined();
                }


                if (wrappedArg0.IsEmpty()) wrappedArg0 = Undefined();

                Handle<Value> args[] = { wrappedArg0 };
                NodeRT::Utils::CallCallbackInDomain(*callbackObjPtr, _countof(args), args);
              });
            })
          );
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }

      }
      else if (NodeRT::Utils::CaseInsenstiveEquals(L"smsMessageReceived", str))
      {
        if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Devices::Sms::SmsDevice^>(args.This()))
        {
          ThrowException(Exception::Error(NodeRT::Utils::NewString(L"The caller of this method isn't of the expected type or internal WinRt object was disposed")));
          return scope.Close(Undefined());
        }
        SmsDevice *wrapper = SmsDevice::Unwrap<SmsDevice>(args.This());
      
        try
        {
          std::shared_ptr<Persistent<Object>> callbackObjPtr(new Persistent<Object>(Persistent<Object>::New(NodeRT::Utils::CreateCallbackObjectInDomain(callback))), 
            [] (Persistent<Object> *ptr ) {
              NodeUtils::Async::RunOnMain([ptr]() {
                ptr->Dispose();
                delete ptr;
            });
          });

          registrationToken = wrapper->_instance->SmsMessageReceived::add(
            ref new ::Windows::Devices::Sms::SmsMessageReceivedEventHandler(
            [callbackObjPtr](::Windows::Devices::Sms::SmsDevice^ arg0, ::Windows::Devices::Sms::SmsMessageReceivedEventArgs^ arg1) {
              NodeUtils::Async::RunOnMain([callbackObjPtr , arg0, arg1]() {
                TryCatch tryCatch;
              
                Handle<Value> error;

                Handle<Value> wrappedArg0 = WrapSmsDevice(arg0);
                Handle<Value> wrappedArg1 = WrapSmsMessageReceivedEventArgs(arg1);

                if (tryCatch.HasCaught())
                {
                  error = tryCatch.Exception()->ToObject();
                }
                else 
                {
                  error = Undefined();
                }


                if (wrappedArg0.IsEmpty()) wrappedArg0 = Undefined();
                if (wrappedArg1.IsEmpty()) wrappedArg1 = Undefined();

                Handle<Value> args[] = { wrappedArg0, wrappedArg1 };
                NodeRT::Utils::CallCallbackInDomain(*callbackObjPtr, _countof(args), args);
              });
            })
          );
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }

      }
      else 
      {
        ThrowException(Exception::Error(String::Concat(NodeRT::Utils::NewString(L"given event name isn't supported: "), args[0].As<String>())));
        return scope.Close(Undefined());
      }

      Local<Value> tokenMap = callback->GetHiddenValue(String::NewSymbol(REGISTRATION_TOKEN_MAP_PROPERTY_NAME));
                
      if (tokenMap.IsEmpty() || tokenMap->Equals(Undefined()))
      {
          tokenMap = Object::New();
          callback->SetHiddenValue(String::NewSymbol(REGISTRATION_TOKEN_MAP_PROPERTY_NAME), tokenMap);
      }

      tokenMap.As<Object>()->Set(args[1], CreateOpaqueWrapper(::Windows::Foundation::PropertyValue::CreateInt64(registrationToken.Value)));
                
      return scope.Close(Undefined());
    }

    static v8::Handle<v8::Value> RemoveListener(const v8::Arguments& args)
    {
      HandleScope scope;

      if (args.Length() < 2 || !args[0]->IsString() || !args[1]->IsFunction())
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"wrong arguments, expected a string and a callback")));
        return scope.Close(Undefined());
      }

      String::Value eventName(args[0]);
      auto str = *eventName;

      if ((NodeRT::Utils::CaseInsenstiveEquals(L"smsDeviceStatusChanged", str)) &&(NodeRT::Utils::CaseInsenstiveEquals(L"smsMessageReceived", str)))
      {
        ThrowException(Exception::Error(String::Concat(NodeRT::Utils::NewString(L"given event name isn't supported: "), args[0].As<String>())));
        return scope.Close(Undefined());
      }

      Local<Function> callback = args[1].As<Function>();
      Handle<Value> tokenMap = callback->GetHiddenValue(String::NewSymbol(REGISTRATION_TOKEN_MAP_PROPERTY_NAME));
                
      if (tokenMap.IsEmpty() || tokenMap->Equals(Undefined()))
      {
        return scope.Close(Undefined());
      }

      Handle<Value> opaqueWrapperObj =  tokenMap.As<Object>()->Get(args[1]);

      if (opaqueWrapperObj.IsEmpty() || opaqueWrapperObj->Equals(Undefined()))
      {
        return scope.Close(Undefined());
      }

      OpaqueWrapper *opaqueWrapper = OpaqueWrapper::Unwrap<OpaqueWrapper>(opaqueWrapperObj.As<Object>());
            
      long long tokenValue = (long long) opaqueWrapper->GetObjectInstance();
      ::Windows::Foundation::EventRegistrationToken registrationToken;
      registrationToken.Value = tokenValue;
        
      try 
      {
        if (NodeRT::Utils::CaseInsenstiveEquals(L"smsDeviceStatusChanged", str))
        {
          if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Devices::Sms::SmsDevice^>(args.This()))
          {
            ThrowException(Exception::Error(NodeRT::Utils::NewString(L"The caller of this method isn't of the expected type or internal WinRt object was disposed")));
            return scope.Close(Undefined());
          }
          SmsDevice *wrapper = SmsDevice::Unwrap<SmsDevice>(args.This());
          wrapper->_instance->SmsDeviceStatusChanged::remove(registrationToken);
        }
        else if (NodeRT::Utils::CaseInsenstiveEquals(L"smsMessageReceived", str))
        {
          if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Devices::Sms::SmsDevice^>(args.This()))
          {
            ThrowException(Exception::Error(NodeRT::Utils::NewString(L"The caller of this method isn't of the expected type or internal WinRt object was disposed")));
            return scope.Close(Undefined());
          }
          SmsDevice *wrapper = SmsDevice::Unwrap<SmsDevice>(args.This());
          wrapper->_instance->SmsMessageReceived::remove(registrationToken);
        }
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
      }

      tokenMap.As<Object>()->Delete(args[0].As<String>());

      return scope.Close(Undefined());
    }
  private:
    ::Windows::Devices::Sms::SmsDevice^ _instance;
    static Persistent<FunctionTemplate> s_constructorTemplate;

    friend v8::Handle<v8::Value> WrapSmsDevice(::Windows::Devices::Sms::SmsDevice^ wintRtInstance);
    friend ::Windows::Devices::Sms::SmsDevice^ UnwrapSmsDevice(Handle<Value> value);
    friend bool IsSmsDeviceWrapper(Handle<Value> value);
  };
  Persistent<FunctionTemplate> SmsDevice::s_constructorTemplate;

  v8::Handle<v8::Value> WrapSmsDevice(::Windows::Devices::Sms::SmsDevice^ winRtInstance)
  {
    HandleScope scope;

    if (winRtInstance == nullptr)
    {
      return scope.Close(Undefined());
    }

    Handle<Object> opaqueWrapper = CreateOpaqueWrapper(winRtInstance);
    Handle<Value> args[] = {opaqueWrapper};
    return scope.Close(SmsDevice::s_constructorTemplate->GetFunction()->NewInstance(_countof(args), args));
  }

  ::Windows::Devices::Sms::SmsDevice^ UnwrapSmsDevice(Handle<Value> value)
  {
     return SmsDevice::Unwrap<SmsDevice>(value.As<Object>())->_instance;
  }

  void InitSmsDevice(Handle<Object> exports)
  {
    SmsDevice::Init(exports);
  }

  class GetSmsDeviceOperation : public WrapperBase
  {
  public:    
    static v8::Handle<v8::Value> Init(const Handle<Object> exports)
    {
      HandleScope scope;
      
      s_constructorTemplate = Persistent<FunctionTemplate>::New(FunctionTemplate::New(New));
      s_constructorTemplate->SetClassName(String::NewSymbol("GetSmsDeviceOperation"));
      s_constructorTemplate->InstanceTemplate()->SetInternalFieldCount(1);
      
            
      s_constructorTemplate->PrototypeTemplate()->Set(String::NewSymbol("getResults"), FunctionTemplate::New(GetResults)->GetFunction());
      s_constructorTemplate->PrototypeTemplate()->Set(String::NewSymbol("cancel"), FunctionTemplate::New(Cancel)->GetFunction());
      s_constructorTemplate->PrototypeTemplate()->Set(String::NewSymbol("close"), FunctionTemplate::New(Close)->GetFunction());
      
                        
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("completed"), CompletedGetter, CompletedSetter);
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("errorCode"), ErrorCodeGetter);
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("id"), IdGetter);
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("status"), StatusGetter);
      
      Local<Function> constructor = s_constructorTemplate->GetFunction();


      exports->Set(String::NewSymbol("GetSmsDeviceOperation"), constructor);
      return scope.Close(Undefined());
    }


    virtual ::Platform::Object^ GetObjectInstance() const override
    {
      return _instance;
    }

  private:
    
    GetSmsDeviceOperation(::Windows::Devices::Sms::GetSmsDeviceOperation^ instance)
    {
      _instance = instance;
    }
    
    
    static v8::Handle<v8::Value> New(const v8::Arguments& args)
    {
      HandleScope scope;

      // in case the constructor was called without the new operator
      if (!s_constructorTemplate->HasInstance(args.This()))
      {
        if (args.Length() > 0)
        {
          std::unique_ptr<Handle<Value> []> constructorArgs(new Handle<Value>[args.Length()]);

          Handle<Value> *argsPtr = constructorArgs.get();
          for (int i = 0; i < args.Length(); i++)
          {
            argsPtr[i] = args[i];
          }

          return s_constructorTemplate->GetFunction()->CallAsConstructor(args.Length(), constructorArgs.get());
        }
        else
        {
          return s_constructorTemplate->GetFunction()->CallAsConstructor(args.Length(), nullptr);
        }
      }
      
      ::Windows::Devices::Sms::GetSmsDeviceOperation^ winRtInstance;


      if (args.Length() == 1 && OpaqueWrapper::IsOpaqueWrapper(args[0]) &&
        NodeRT::Utils::IsWinRtWrapperOf<::Windows::Devices::Sms::GetSmsDeviceOperation^>(args[0]))
      {
        try 
        {
          winRtInstance = (::Windows::Devices::Sms::GetSmsDeviceOperation^) NodeRT::Utils::GetObjectInstance(args[0]);
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Invalid arguments, no suitable constructor found")));
        return scope.Close(Undefined());
      }

      args.This()->SetHiddenValue(String::NewSymbol("__winRtInstance__"), True());

      GetSmsDeviceOperation *wrapperInstance = new GetSmsDeviceOperation(winRtInstance);
      wrapperInstance->Wrap(args.This());

      return args.This();
    }


  
    static Handle<Value> GetResults(const v8::Arguments& args)
    {
      HandleScope scope;

      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Devices::Sms::GetSmsDeviceOperation^>(args.This()))
      {
        return scope.Close(Undefined());
      }

      GetSmsDeviceOperation *wrapper = GetSmsDeviceOperation::Unwrap<GetSmsDeviceOperation>(args.This());

      if (args.Length() == 0)
      {
        try
        {
          ::Windows::Devices::Sms::SmsDevice^ result;
          result = wrapper->_instance->GetResults();
          return scope.Close(WrapSmsDevice(result));
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else 
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Bad arguments: no suitable overload found")));
        return scope.Close(Undefined());
      }

      return scope.Close(Undefined());
    }
    static Handle<Value> Cancel(const v8::Arguments& args)
    {
      HandleScope scope;

      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Devices::Sms::GetSmsDeviceOperation^>(args.This()))
      {
        return scope.Close(Undefined());
      }

      GetSmsDeviceOperation *wrapper = GetSmsDeviceOperation::Unwrap<GetSmsDeviceOperation>(args.This());

      if (args.Length() == 0)
      {
        try
        {
          wrapper->_instance->Cancel();
          return scope.Close(Undefined());   
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else 
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Bad arguments: no suitable overload found")));
        return scope.Close(Undefined());
      }

      return scope.Close(Undefined());
    }
    static Handle<Value> Close(const v8::Arguments& args)
    {
      HandleScope scope;

      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Devices::Sms::GetSmsDeviceOperation^>(args.This()))
      {
        return scope.Close(Undefined());
      }

      GetSmsDeviceOperation *wrapper = GetSmsDeviceOperation::Unwrap<GetSmsDeviceOperation>(args.This());

      if (args.Length() == 0)
      {
        try
        {
          wrapper->_instance->Close();
          return scope.Close(Undefined());   
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else 
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Bad arguments: no suitable overload found")));
        return scope.Close(Undefined());
      }

      return scope.Close(Undefined());
    }



    static Handle<Value> CompletedGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Devices::Sms::GetSmsDeviceOperation^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      GetSmsDeviceOperation *wrapper = GetSmsDeviceOperation::Unwrap<GetSmsDeviceOperation>(info.This());

      try 
      {
        ::Windows::Foundation::AsyncOperationCompletedHandler<::Windows::Devices::Sms::SmsDevice^>^ result = wrapper->_instance->Completed;
        return scope.Close(NodeRT::Utils::CreateExternalWinRTObject("Windows.Foundation", "AsyncOperationCompletedHandler`1", result));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    
    static void CompletedSetter(Local<String> property, Local<Value> value, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Foundation::AsyncOperationCompletedHandler<::Windows::Devices::Sms::SmsDevice^>^>(value))
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Value to set is of unexpected type")));
        return;
      }

      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Devices::Sms::GetSmsDeviceOperation^>(info.This()))
      {
        return;
      }

      GetSmsDeviceOperation *wrapper = GetSmsDeviceOperation::Unwrap<GetSmsDeviceOperation>(info.This());

      try 
      {
        
        ::Windows::Foundation::AsyncOperationCompletedHandler<::Windows::Devices::Sms::SmsDevice^>^ winRtValue = dynamic_cast<::Windows::Foundation::AsyncOperationCompletedHandler<::Windows::Devices::Sms::SmsDevice^>^>(NodeRT::Utils::GetObjectInstance(value));

        wrapper->_instance->Completed = winRtValue;
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
      }
    }
    
    static Handle<Value> ErrorCodeGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Devices::Sms::GetSmsDeviceOperation^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      GetSmsDeviceOperation *wrapper = GetSmsDeviceOperation::Unwrap<GetSmsDeviceOperation>(info.This());

      try 
      {
        ::Windows::Foundation::HResult result = wrapper->_instance->ErrorCode;
        return scope.Close(Integer::New(result.Value));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    
    static Handle<Value> IdGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Devices::Sms::GetSmsDeviceOperation^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      GetSmsDeviceOperation *wrapper = GetSmsDeviceOperation::Unwrap<GetSmsDeviceOperation>(info.This());

      try 
      {
        unsigned int result = wrapper->_instance->Id;
        return scope.Close(Integer::New(result));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    
    static Handle<Value> StatusGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Devices::Sms::GetSmsDeviceOperation^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      GetSmsDeviceOperation *wrapper = GetSmsDeviceOperation::Unwrap<GetSmsDeviceOperation>(info.This());

      try 
      {
        ::Windows::Foundation::AsyncStatus result = wrapper->_instance->Status;
        return scope.Close(Integer::New(static_cast<int>(result)));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    


  private:
    ::Windows::Devices::Sms::GetSmsDeviceOperation^ _instance;
    static Persistent<FunctionTemplate> s_constructorTemplate;

    friend v8::Handle<v8::Value> WrapGetSmsDeviceOperation(::Windows::Devices::Sms::GetSmsDeviceOperation^ wintRtInstance);
    friend ::Windows::Devices::Sms::GetSmsDeviceOperation^ UnwrapGetSmsDeviceOperation(Handle<Value> value);
    friend bool IsGetSmsDeviceOperationWrapper(Handle<Value> value);
  };
  Persistent<FunctionTemplate> GetSmsDeviceOperation::s_constructorTemplate;

  v8::Handle<v8::Value> WrapGetSmsDeviceOperation(::Windows::Devices::Sms::GetSmsDeviceOperation^ winRtInstance)
  {
    HandleScope scope;

    if (winRtInstance == nullptr)
    {
      return scope.Close(Undefined());
    }

    Handle<Object> opaqueWrapper = CreateOpaqueWrapper(winRtInstance);
    Handle<Value> args[] = {opaqueWrapper};
    return scope.Close(GetSmsDeviceOperation::s_constructorTemplate->GetFunction()->NewInstance(_countof(args), args));
  }

  ::Windows::Devices::Sms::GetSmsDeviceOperation^ UnwrapGetSmsDeviceOperation(Handle<Value> value)
  {
     return GetSmsDeviceOperation::Unwrap<GetSmsDeviceOperation>(value.As<Object>())->_instance;
  }

  void InitGetSmsDeviceOperation(Handle<Object> exports)
  {
    GetSmsDeviceOperation::Init(exports);
  }

  class ISmsDevice : public WrapperBase
  {
  public:    
    static v8::Handle<v8::Value> Init(const Handle<Object> exports)
    {
      HandleScope scope;
      
      s_constructorTemplate = Persistent<FunctionTemplate>::New(FunctionTemplate::New(New));
      s_constructorTemplate->SetClassName(String::NewSymbol("ISmsDevice"));
      s_constructorTemplate->InstanceTemplate()->SetInternalFieldCount(1);
      
      Handle<Value> asyncSymbol = String::NewSymbol("__winRtAsync__");
      Handle<Function> func;
            
      s_constructorTemplate->PrototypeTemplate()->Set(String::NewSymbol("calculateLength"), FunctionTemplate::New(CalculateLength)->GetFunction());
      
            
      func = FunctionTemplate::New(SendMessageAsync)->GetFunction();
      func->Set(asyncSymbol, True(), PropertyAttribute::DontEnum);
      s_constructorTemplate->PrototypeTemplate()->Set(String::NewSymbol("sendMessageAsync"), func);
      
            
      Local<Function> addListenerFunc = FunctionTemplate::New(AddListener)->GetFunction();
      s_constructorTemplate->PrototypeTemplate()->Set(String::NewSymbol("addListener"), addListenerFunc);
      s_constructorTemplate->PrototypeTemplate()->Set(String::NewSymbol("on"), addListenerFunc);
      Local<Function> removeListenerFunc = FunctionTemplate::New(RemoveListener)->GetFunction();
      s_constructorTemplate->PrototypeTemplate()->Set(String::NewSymbol("removeListener"), removeListenerFunc);
      s_constructorTemplate->PrototypeTemplate()->Set(String::NewSymbol("off"), removeListenerFunc);
            
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("accountPhoneNumber"), AccountPhoneNumberGetter);
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("cellularClass"), CellularClassGetter);
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("deviceStatus"), DeviceStatusGetter);
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("messageStore"), MessageStoreGetter);
      
      Local<Function> constructor = s_constructorTemplate->GetFunction();


      exports->Set(String::NewSymbol("ISmsDevice"), constructor);
      return scope.Close(Undefined());
    }


    virtual ::Platform::Object^ GetObjectInstance() const override
    {
      return _instance;
    }

  private:
    
    ISmsDevice(::Windows::Devices::Sms::ISmsDevice^ instance)
    {
      _instance = instance;
    }
    
    
    static v8::Handle<v8::Value> New(const v8::Arguments& args)
    {
      HandleScope scope;

      // in case the constructor was called without the new operator
      if (!s_constructorTemplate->HasInstance(args.This()))
      {
        if (args.Length() > 0)
        {
          std::unique_ptr<Handle<Value> []> constructorArgs(new Handle<Value>[args.Length()]);

          Handle<Value> *argsPtr = constructorArgs.get();
          for (int i = 0; i < args.Length(); i++)
          {
            argsPtr[i] = args[i];
          }

          return s_constructorTemplate->GetFunction()->CallAsConstructor(args.Length(), constructorArgs.get());
        }
        else
        {
          return s_constructorTemplate->GetFunction()->CallAsConstructor(args.Length(), nullptr);
        }
      }
      
      ::Windows::Devices::Sms::ISmsDevice^ winRtInstance;


      if (args.Length() == 1 && OpaqueWrapper::IsOpaqueWrapper(args[0]) &&
        NodeRT::Utils::IsWinRtWrapperOf<::Windows::Devices::Sms::ISmsDevice^>(args[0]))
      {
        try 
        {
          winRtInstance = (::Windows::Devices::Sms::ISmsDevice^) NodeRT::Utils::GetObjectInstance(args[0]);
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Invalid arguments, no suitable constructor found")));
        return scope.Close(Undefined());
      }

      args.This()->SetHiddenValue(String::NewSymbol("__winRtInstance__"), True());

      ISmsDevice *wrapperInstance = new ISmsDevice(winRtInstance);
      wrapperInstance->Wrap(args.This());

      return args.This();
    }


    static Handle<Value> SendMessageAsync(const v8::Arguments& args)
    {
      HandleScope scope;

      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Devices::Sms::ISmsDevice^>(args.This()))
      {
        return scope.Close(Undefined());
      }

      if (args.Length() == 0 || !args[args.Length() -1]->IsFunction())
      {
          ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Bad arguments: No callback was given")));
          return scope.Close(Undefined());
      }

      ISmsDevice *wrapper = ISmsDevice::Unwrap<ISmsDevice>(args.This());

      ::Windows::Devices::Sms::SendSmsMessageOperation^ op;
    

      if (args.Length() == 2
        && NodeRT::Utils::IsWinRtWrapperOf<::Windows::Devices::Sms::ISmsMessage^>(args[0]))
      {
        try
        {
          ::Windows::Devices::Sms::ISmsMessage^ arg0 = UnwrapISmsMessage(args[0]);
          
          op = wrapper->_instance->SendMessageAsync(arg0);
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else 
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Bad arguments: no suitable overload found")));
        return scope.Close(Undefined());
      }
    
      auto opTask = create_task(op);
      uv_async_t* asyncToken = NodeUtils::Async::GetAsyncToken(args[args.Length() -1].As<Function>());

      opTask.then( [asyncToken] (task<void> t) 
      {	
        try
        {
          t.get();
          NodeUtils::Async::RunCallbackOnMain(asyncToken, [](NodeUtils::InvokeCallbackDelegate invokeCallback) {


            Handle<Value> args[] = {Undefined()};

            invokeCallback(_countof(args), args);
          });
        }
        catch (Platform::Exception^ exception)
        {
          NodeUtils::Async::RunCallbackOnMain(asyncToken, [exception](NodeUtils::InvokeCallbackDelegate invokeCallback) {
             
            Handle<Value> error = NodeRT::Utils::WinRtExceptionToJsError(exception);
        
            Handle<Value> args[] = {error};
            invokeCallback(_countof(args), args);
          });
        }  		
      });

      return scope.Close(Undefined());
    }
  
    static Handle<Value> CalculateLength(const v8::Arguments& args)
    {
      HandleScope scope;

      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Devices::Sms::ISmsDevice^>(args.This()))
      {
        return scope.Close(Undefined());
      }

      ISmsDevice *wrapper = ISmsDevice::Unwrap<ISmsDevice>(args.This());

      if (args.Length() == 1
        && NodeRT::Utils::IsWinRtWrapperOf<::Windows::Devices::Sms::SmsTextMessage^>(args[0]))
      {
        try
        {
          ::Windows::Devices::Sms::SmsTextMessage^ arg0 = UnwrapSmsTextMessage(args[0]);
          
          ::Windows::Devices::Sms::SmsEncodedLength result;
          result = wrapper->_instance->CalculateLength(arg0);
          return scope.Close(SmsEncodedLengthToJsObject(result));
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else 
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Bad arguments: no suitable overload found")));
        return scope.Close(Undefined());
      }

      return scope.Close(Undefined());
    }



    static Handle<Value> AccountPhoneNumberGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Devices::Sms::ISmsDevice^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      ISmsDevice *wrapper = ISmsDevice::Unwrap<ISmsDevice>(info.This());

      try 
      {
        Platform::String^ result = wrapper->_instance->AccountPhoneNumber;
        return scope.Close(NodeRT::Utils::NewString(result->Data()));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    
    static Handle<Value> CellularClassGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Devices::Sms::ISmsDevice^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      ISmsDevice *wrapper = ISmsDevice::Unwrap<ISmsDevice>(info.This());

      try 
      {
        ::Windows::Devices::Sms::CellularClass result = wrapper->_instance->CellularClass;
        return scope.Close(Integer::New(static_cast<int>(result)));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    
    static Handle<Value> DeviceStatusGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Devices::Sms::ISmsDevice^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      ISmsDevice *wrapper = ISmsDevice::Unwrap<ISmsDevice>(info.This());

      try 
      {
        ::Windows::Devices::Sms::SmsDeviceStatus result = wrapper->_instance->DeviceStatus;
        return scope.Close(Integer::New(static_cast<int>(result)));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    
    static Handle<Value> MessageStoreGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Devices::Sms::ISmsDevice^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      ISmsDevice *wrapper = ISmsDevice::Unwrap<ISmsDevice>(info.This());

      try 
      {
        ::Windows::Devices::Sms::SmsDeviceMessageStore^ result = wrapper->_instance->MessageStore;
        return scope.Close(WrapSmsDeviceMessageStore(result));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    


    static v8::Handle<v8::Value> AddListener(const v8::Arguments& args)
    {
      HandleScope scope;

      if (args.Length() < 2 || !args[0]->IsString() || !args[1]->IsFunction())
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"wrong arguments, expected arguments are eventName(string),callback(function)")));
        return scope.Close(Undefined());
      }

      String::Value eventName(args[0]);
      auto str = *eventName;
      
      Local<Function> callback = args[1].As<Function>();
      
      ::Windows::Foundation::EventRegistrationToken registrationToken;
      if (NodeRT::Utils::CaseInsenstiveEquals(L"smsDeviceStatusChanged", str))
      {
        if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Devices::Sms::ISmsDevice^>(args.This()))
        {
          ThrowException(Exception::Error(NodeRT::Utils::NewString(L"The caller of this method isn't of the expected type or internal WinRt object was disposed")));
          return scope.Close(Undefined());
        }
        ISmsDevice *wrapper = ISmsDevice::Unwrap<ISmsDevice>(args.This());
      
        try
        {
          std::shared_ptr<Persistent<Object>> callbackObjPtr(new Persistent<Object>(Persistent<Object>::New(NodeRT::Utils::CreateCallbackObjectInDomain(callback))), 
            [] (Persistent<Object> *ptr ) {
              NodeUtils::Async::RunOnMain([ptr]() {
                ptr->Dispose();
                delete ptr;
            });
          });

          registrationToken = wrapper->_instance->SmsDeviceStatusChanged::add(
            ref new ::Windows::Devices::Sms::SmsDeviceStatusChangedEventHandler(
            [callbackObjPtr](::Windows::Devices::Sms::SmsDevice^ arg0) {
              NodeUtils::Async::RunOnMain([callbackObjPtr , arg0]() {
                TryCatch tryCatch;
              
                Handle<Value> error;

                Handle<Value> wrappedArg0 = WrapSmsDevice(arg0);

                if (tryCatch.HasCaught())
                {
                  error = tryCatch.Exception()->ToObject();
                }
                else 
                {
                  error = Undefined();
                }


                if (wrappedArg0.IsEmpty()) wrappedArg0 = Undefined();

                Handle<Value> args[] = { wrappedArg0 };
                NodeRT::Utils::CallCallbackInDomain(*callbackObjPtr, _countof(args), args);
              });
            })
          );
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }

      }
      else if (NodeRT::Utils::CaseInsenstiveEquals(L"smsMessageReceived", str))
      {
        if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Devices::Sms::ISmsDevice^>(args.This()))
        {
          ThrowException(Exception::Error(NodeRT::Utils::NewString(L"The caller of this method isn't of the expected type or internal WinRt object was disposed")));
          return scope.Close(Undefined());
        }
        ISmsDevice *wrapper = ISmsDevice::Unwrap<ISmsDevice>(args.This());
      
        try
        {
          std::shared_ptr<Persistent<Object>> callbackObjPtr(new Persistent<Object>(Persistent<Object>::New(NodeRT::Utils::CreateCallbackObjectInDomain(callback))), 
            [] (Persistent<Object> *ptr ) {
              NodeUtils::Async::RunOnMain([ptr]() {
                ptr->Dispose();
                delete ptr;
            });
          });

          registrationToken = wrapper->_instance->SmsMessageReceived::add(
            ref new ::Windows::Devices::Sms::SmsMessageReceivedEventHandler(
            [callbackObjPtr](::Windows::Devices::Sms::SmsDevice^ arg0, ::Windows::Devices::Sms::SmsMessageReceivedEventArgs^ arg1) {
              NodeUtils::Async::RunOnMain([callbackObjPtr , arg0, arg1]() {
                TryCatch tryCatch;
              
                Handle<Value> error;

                Handle<Value> wrappedArg0 = WrapSmsDevice(arg0);
                Handle<Value> wrappedArg1 = WrapSmsMessageReceivedEventArgs(arg1);

                if (tryCatch.HasCaught())
                {
                  error = tryCatch.Exception()->ToObject();
                }
                else 
                {
                  error = Undefined();
                }


                if (wrappedArg0.IsEmpty()) wrappedArg0 = Undefined();
                if (wrappedArg1.IsEmpty()) wrappedArg1 = Undefined();

                Handle<Value> args[] = { wrappedArg0, wrappedArg1 };
                NodeRT::Utils::CallCallbackInDomain(*callbackObjPtr, _countof(args), args);
              });
            })
          );
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }

      }
      else 
      {
        ThrowException(Exception::Error(String::Concat(NodeRT::Utils::NewString(L"given event name isn't supported: "), args[0].As<String>())));
        return scope.Close(Undefined());
      }

      Local<Value> tokenMap = callback->GetHiddenValue(String::NewSymbol(REGISTRATION_TOKEN_MAP_PROPERTY_NAME));
                
      if (tokenMap.IsEmpty() || tokenMap->Equals(Undefined()))
      {
          tokenMap = Object::New();
          callback->SetHiddenValue(String::NewSymbol(REGISTRATION_TOKEN_MAP_PROPERTY_NAME), tokenMap);
      }

      tokenMap.As<Object>()->Set(args[1], CreateOpaqueWrapper(::Windows::Foundation::PropertyValue::CreateInt64(registrationToken.Value)));
                
      return scope.Close(Undefined());
    }

    static v8::Handle<v8::Value> RemoveListener(const v8::Arguments& args)
    {
      HandleScope scope;

      if (args.Length() < 2 || !args[0]->IsString() || !args[1]->IsFunction())
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"wrong arguments, expected a string and a callback")));
        return scope.Close(Undefined());
      }

      String::Value eventName(args[0]);
      auto str = *eventName;

      if ((NodeRT::Utils::CaseInsenstiveEquals(L"smsDeviceStatusChanged", str)) &&(NodeRT::Utils::CaseInsenstiveEquals(L"smsMessageReceived", str)))
      {
        ThrowException(Exception::Error(String::Concat(NodeRT::Utils::NewString(L"given event name isn't supported: "), args[0].As<String>())));
        return scope.Close(Undefined());
      }

      Local<Function> callback = args[1].As<Function>();
      Handle<Value> tokenMap = callback->GetHiddenValue(String::NewSymbol(REGISTRATION_TOKEN_MAP_PROPERTY_NAME));
                
      if (tokenMap.IsEmpty() || tokenMap->Equals(Undefined()))
      {
        return scope.Close(Undefined());
      }

      Handle<Value> opaqueWrapperObj =  tokenMap.As<Object>()->Get(args[1]);

      if (opaqueWrapperObj.IsEmpty() || opaqueWrapperObj->Equals(Undefined()))
      {
        return scope.Close(Undefined());
      }

      OpaqueWrapper *opaqueWrapper = OpaqueWrapper::Unwrap<OpaqueWrapper>(opaqueWrapperObj.As<Object>());
            
      long long tokenValue = (long long) opaqueWrapper->GetObjectInstance();
      ::Windows::Foundation::EventRegistrationToken registrationToken;
      registrationToken.Value = tokenValue;
        
      try 
      {
        if (NodeRT::Utils::CaseInsenstiveEquals(L"smsDeviceStatusChanged", str))
        {
          if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Devices::Sms::ISmsDevice^>(args.This()))
          {
            ThrowException(Exception::Error(NodeRT::Utils::NewString(L"The caller of this method isn't of the expected type or internal WinRt object was disposed")));
            return scope.Close(Undefined());
          }
          ISmsDevice *wrapper = ISmsDevice::Unwrap<ISmsDevice>(args.This());
          wrapper->_instance->SmsDeviceStatusChanged::remove(registrationToken);
        }
        else if (NodeRT::Utils::CaseInsenstiveEquals(L"smsMessageReceived", str))
        {
          if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Devices::Sms::ISmsDevice^>(args.This()))
          {
            ThrowException(Exception::Error(NodeRT::Utils::NewString(L"The caller of this method isn't of the expected type or internal WinRt object was disposed")));
            return scope.Close(Undefined());
          }
          ISmsDevice *wrapper = ISmsDevice::Unwrap<ISmsDevice>(args.This());
          wrapper->_instance->SmsMessageReceived::remove(registrationToken);
        }
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
      }

      tokenMap.As<Object>()->Delete(args[0].As<String>());

      return scope.Close(Undefined());
    }
  private:
    ::Windows::Devices::Sms::ISmsDevice^ _instance;
    static Persistent<FunctionTemplate> s_constructorTemplate;

    friend v8::Handle<v8::Value> WrapISmsDevice(::Windows::Devices::Sms::ISmsDevice^ wintRtInstance);
    friend ::Windows::Devices::Sms::ISmsDevice^ UnwrapISmsDevice(Handle<Value> value);
    friend bool IsISmsDeviceWrapper(Handle<Value> value);
  };
  Persistent<FunctionTemplate> ISmsDevice::s_constructorTemplate;

  v8::Handle<v8::Value> WrapISmsDevice(::Windows::Devices::Sms::ISmsDevice^ winRtInstance)
  {
    HandleScope scope;

    if (winRtInstance == nullptr)
    {
      return scope.Close(Undefined());
    }

    Handle<Object> opaqueWrapper = CreateOpaqueWrapper(winRtInstance);
    Handle<Value> args[] = {opaqueWrapper};
    return scope.Close(ISmsDevice::s_constructorTemplate->GetFunction()->NewInstance(_countof(args), args));
  }

  ::Windows::Devices::Sms::ISmsDevice^ UnwrapISmsDevice(Handle<Value> value)
  {
     return ISmsDevice::Unwrap<ISmsDevice>(value.As<Object>())->_instance;
  }

  void InitISmsDevice(Handle<Object> exports)
  {
    ISmsDevice::Init(exports);
  }

  class SmsReceivedEventDetails : public WrapperBase
  {
  public:    
    static v8::Handle<v8::Value> Init(const Handle<Object> exports)
    {
      HandleScope scope;
      
      s_constructorTemplate = Persistent<FunctionTemplate>::New(FunctionTemplate::New(New));
      s_constructorTemplate->SetClassName(String::NewSymbol("SmsReceivedEventDetails"));
      s_constructorTemplate->InstanceTemplate()->SetInternalFieldCount(1);
      
                              
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("deviceId"), DeviceIdGetter);
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("messageIndex"), MessageIndexGetter);
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("binaryMessage"), BinaryMessageGetter);
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("messageClass"), MessageClassGetter);
      
      Local<Function> constructor = s_constructorTemplate->GetFunction();


      exports->Set(String::NewSymbol("SmsReceivedEventDetails"), constructor);
      return scope.Close(Undefined());
    }


    virtual ::Platform::Object^ GetObjectInstance() const override
    {
      return _instance;
    }

  private:
    
    SmsReceivedEventDetails(::Windows::Devices::Sms::SmsReceivedEventDetails^ instance)
    {
      _instance = instance;
    }
    
    
    static v8::Handle<v8::Value> New(const v8::Arguments& args)
    {
      HandleScope scope;

      // in case the constructor was called without the new operator
      if (!s_constructorTemplate->HasInstance(args.This()))
      {
        if (args.Length() > 0)
        {
          std::unique_ptr<Handle<Value> []> constructorArgs(new Handle<Value>[args.Length()]);

          Handle<Value> *argsPtr = constructorArgs.get();
          for (int i = 0; i < args.Length(); i++)
          {
            argsPtr[i] = args[i];
          }

          return s_constructorTemplate->GetFunction()->CallAsConstructor(args.Length(), constructorArgs.get());
        }
        else
        {
          return s_constructorTemplate->GetFunction()->CallAsConstructor(args.Length(), nullptr);
        }
      }
      
      ::Windows::Devices::Sms::SmsReceivedEventDetails^ winRtInstance;


      if (args.Length() == 1 && OpaqueWrapper::IsOpaqueWrapper(args[0]) &&
        NodeRT::Utils::IsWinRtWrapperOf<::Windows::Devices::Sms::SmsReceivedEventDetails^>(args[0]))
      {
        try 
        {
          winRtInstance = (::Windows::Devices::Sms::SmsReceivedEventDetails^) NodeRT::Utils::GetObjectInstance(args[0]);
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Invalid arguments, no suitable constructor found")));
        return scope.Close(Undefined());
      }

      args.This()->SetHiddenValue(String::NewSymbol("__winRtInstance__"), True());

      SmsReceivedEventDetails *wrapperInstance = new SmsReceivedEventDetails(winRtInstance);
      wrapperInstance->Wrap(args.This());

      return args.This();
    }


  



    static Handle<Value> DeviceIdGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Devices::Sms::SmsReceivedEventDetails^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      SmsReceivedEventDetails *wrapper = SmsReceivedEventDetails::Unwrap<SmsReceivedEventDetails>(info.This());

      try 
      {
        Platform::String^ result = wrapper->_instance->DeviceId;
        return scope.Close(NodeRT::Utils::NewString(result->Data()));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    
    static Handle<Value> MessageIndexGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Devices::Sms::SmsReceivedEventDetails^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      SmsReceivedEventDetails *wrapper = SmsReceivedEventDetails::Unwrap<SmsReceivedEventDetails>(info.This());

      try 
      {
        unsigned int result = wrapper->_instance->MessageIndex;
        return scope.Close(Integer::New(result));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    
    static Handle<Value> BinaryMessageGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Devices::Sms::SmsReceivedEventDetails^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      SmsReceivedEventDetails *wrapper = SmsReceivedEventDetails::Unwrap<SmsReceivedEventDetails>(info.This());

      try 
      {
        ::Windows::Devices::Sms::SmsBinaryMessage^ result = wrapper->_instance->BinaryMessage;
        return scope.Close(WrapSmsBinaryMessage(result));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    
    static Handle<Value> MessageClassGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Devices::Sms::SmsReceivedEventDetails^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      SmsReceivedEventDetails *wrapper = SmsReceivedEventDetails::Unwrap<SmsReceivedEventDetails>(info.This());

      try 
      {
        ::Windows::Devices::Sms::SmsMessageClass result = wrapper->_instance->MessageClass;
        return scope.Close(Integer::New(static_cast<int>(result)));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    


  private:
    ::Windows::Devices::Sms::SmsReceivedEventDetails^ _instance;
    static Persistent<FunctionTemplate> s_constructorTemplate;

    friend v8::Handle<v8::Value> WrapSmsReceivedEventDetails(::Windows::Devices::Sms::SmsReceivedEventDetails^ wintRtInstance);
    friend ::Windows::Devices::Sms::SmsReceivedEventDetails^ UnwrapSmsReceivedEventDetails(Handle<Value> value);
    friend bool IsSmsReceivedEventDetailsWrapper(Handle<Value> value);
  };
  Persistent<FunctionTemplate> SmsReceivedEventDetails::s_constructorTemplate;

  v8::Handle<v8::Value> WrapSmsReceivedEventDetails(::Windows::Devices::Sms::SmsReceivedEventDetails^ winRtInstance)
  {
    HandleScope scope;

    if (winRtInstance == nullptr)
    {
      return scope.Close(Undefined());
    }

    Handle<Object> opaqueWrapper = CreateOpaqueWrapper(winRtInstance);
    Handle<Value> args[] = {opaqueWrapper};
    return scope.Close(SmsReceivedEventDetails::s_constructorTemplate->GetFunction()->NewInstance(_countof(args), args));
  }

  ::Windows::Devices::Sms::SmsReceivedEventDetails^ UnwrapSmsReceivedEventDetails(Handle<Value> value)
  {
     return SmsReceivedEventDetails::Unwrap<SmsReceivedEventDetails>(value.As<Object>())->_instance;
  }

  void InitSmsReceivedEventDetails(Handle<Object> exports)
  {
    SmsReceivedEventDetails::Init(exports);
  }

} } } } 

void init(Handle<Object> exports)
{
  if (FAILED(CoInitializeEx(nullptr, COINIT_MULTITHREADED)))
  {
    ThrowException(v8::Exception::Error(NodeRT::Utils::NewString(L"error in CoInitializeEx()")));
    return;
  }
  
  NodeRT::Windows::Devices::Sms::InitSmsMessageClassEnum(exports);
  NodeRT::Windows::Devices::Sms::InitSmsDataFormatEnum(exports);
  NodeRT::Windows::Devices::Sms::InitSmsEncodingEnum(exports);
  NodeRT::Windows::Devices::Sms::InitSmsMessageFilterEnum(exports);
  NodeRT::Windows::Devices::Sms::InitSmsMessageTypeEnum(exports);
  NodeRT::Windows::Devices::Sms::InitCellularClassEnum(exports);
  NodeRT::Windows::Devices::Sms::InitSmsDeviceStatusEnum(exports);
  NodeRT::Windows::Devices::Sms::InitISmsMessage(exports);
  NodeRT::Windows::Devices::Sms::InitISmsBinaryMessage(exports);
  NodeRT::Windows::Devices::Sms::InitSmsBinaryMessage(exports);
  NodeRT::Windows::Devices::Sms::InitISmsTextMessage(exports);
  NodeRT::Windows::Devices::Sms::InitSmsTextMessage(exports);
  NodeRT::Windows::Devices::Sms::InitDeleteSmsMessageOperation(exports);
  NodeRT::Windows::Devices::Sms::InitDeleteSmsMessagesOperation(exports);
  NodeRT::Windows::Devices::Sms::InitGetSmsMessageOperation(exports);
  NodeRT::Windows::Devices::Sms::InitGetSmsMessagesOperation(exports);
  NodeRT::Windows::Devices::Sms::InitSmsDeviceMessageStore(exports);
  NodeRT::Windows::Devices::Sms::InitSendSmsMessageOperation(exports);
  NodeRT::Windows::Devices::Sms::InitSmsMessageReceivedEventArgs(exports);
  NodeRT::Windows::Devices::Sms::InitSmsDevice(exports);
  NodeRT::Windows::Devices::Sms::InitGetSmsDeviceOperation(exports);
  NodeRT::Windows::Devices::Sms::InitISmsDevice(exports);
  NodeRT::Windows::Devices::Sms::InitSmsReceivedEventDetails(exports);

  NodeRT::Utils::RegisterNameSpace("Windows.Devices.Sms", exports);
}


NODE_MODULE(binding, init)